"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Web(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTING_ENVIRONMENTS_FIELD_NUMBER: builtins.int
    SERVERFARMS_FIELD_NUMBER: builtins.int
    SERVERFARMS_VIRTUAL_NETWORK_CONNECTIONS_GATEWAYS_FIELD_NUMBER: builtins.int
    SERVERFARMS_VIRTUAL_NETWORK_CONNECTIONS_ROUTES_FIELD_NUMBER: builtins.int
    SITES_FIELD_NUMBER: builtins.int
    SITES_CONFIG_FIELD_NUMBER: builtins.int
    SITES_DEPLOYMENTS_FIELD_NUMBER: builtins.int
    SITES_HOST_NAME_BINDINGS_FIELD_NUMBER: builtins.int
    @property
    def hosting_environments(self) -> global___HostingEnvironments: ...
    @property
    def serverfarms(self) -> global___Serverfarms: ...
    @property
    def serverfarms_virtual_network_connections_gateways(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerfarmsVirtualNetworkConnectionsGateways]: ...
    @property
    def serverfarms_virtual_network_connections_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerfarmsVirtualNetworkConnectionsRoutes]: ...
    @property
    def sites(self) -> global___Sites: ...
    @property
    def sites_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SiteConfig]: ...
    @property
    def sites_deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesDeployments]: ...
    @property
    def sites_host_name_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesHostNameBindings]: ...
    def __init__(
        self,
        *,
        hosting_environments: global___HostingEnvironments | None = ...,
        serverfarms: global___Serverfarms | None = ...,
        serverfarms_virtual_network_connections_gateways: collections.abc.Iterable[global___ServerfarmsVirtualNetworkConnectionsGateways] | None = ...,
        serverfarms_virtual_network_connections_routes: collections.abc.Iterable[global___ServerfarmsVirtualNetworkConnectionsRoutes] | None = ...,
        sites: global___Sites | None = ...,
        sites_config: collections.abc.Iterable[global___SiteConfig] | None = ...,
        sites_deployments: collections.abc.Iterable[global___SitesDeployments] | None = ...,
        sites_host_name_bindings: collections.abc.Iterable[global___SitesHostNameBindings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosting_environments", b"hosting_environments", "serverfarms", b"serverfarms", "sites", b"sites"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosting_environments", b"hosting_environments", "serverfarms", b"serverfarms", "serverfarms_virtual_network_connections_gateways", b"serverfarms_virtual_network_connections_gateways", "serverfarms_virtual_network_connections_routes", b"serverfarms_virtual_network_connections_routes", "sites", b"sites", "sites_config", b"sites_config", "sites_deployments", b"sites_deployments", "sites_host_name_bindings", b"sites_host_name_bindings"]) -> None: ...

global___Microsoft_Web = Microsoft_Web

@typing_extensions.final
class StaticSitesUserProvidedFunctionApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FUNCTION_APP_REGION_FIELD_NUMBER: builtins.int
    FUNCTION_APP_RESOURCE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    function_app_region: builtins.str
    function_app_resource_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        function_app_region: builtins.str = ...,
        function_app_resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["function_app_region", b"function_app_region", "function_app_resource_id", b"function_app_resource_id", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StaticSitesUserProvidedFunctionApps = StaticSitesUserProvidedFunctionApps

@typing_extensions.final
class StaticSitesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___StaticSitesPrivateEndpointConnections = StaticSitesPrivateEndpointConnections

@typing_extensions.final
class StaticSitesLinkedBackends(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKEND_RESOURCE_ID_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    backend_resource_id: builtins.str
    region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        backend_resource_id: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_resource_id", b"backend_resource_id", "kind", b"kind", "name", b"name", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___StaticSitesLinkedBackends = StaticSitesLinkedBackends

@typing_extensions.final
class StaticSitesCustomDomains(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALIDATION_METHOD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    validation_method: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        validation_method: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "resource_info", b"resource_info", "validation_method", b"validation_method"]) -> None: ...

global___StaticSitesCustomDomains = StaticSitesCustomDomains

@typing_extensions.final
class StaticSitesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___StaticSitesConfig = StaticSitesConfig

@typing_extensions.final
class StaticSitesBuildsUserProvidedFunctionApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FUNCTION_APP_REGION_FIELD_NUMBER: builtins.int
    FUNCTION_APP_RESOURCE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    function_app_region: builtins.str
    function_app_resource_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        function_app_region: builtins.str = ...,
        function_app_resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["function_app_region", b"function_app_region", "function_app_resource_id", b"function_app_resource_id", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StaticSitesBuildsUserProvidedFunctionApps = StaticSitesBuildsUserProvidedFunctionApps

@typing_extensions.final
class StaticSitesBuildsLinkedBackends(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKEND_RESOURCE_ID_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    backend_resource_id: builtins.str
    region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        backend_resource_id: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_resource_id", b"backend_resource_id", "kind", b"kind", "name", b"name", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___StaticSitesBuildsLinkedBackends = StaticSitesBuildsLinkedBackends

@typing_extensions.final
class StaticSitesBuildsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___StaticSitesBuildsConfig = StaticSitesBuildsConfig

@typing_extensions.final
class StaticSites(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOW_CONFIG_FILE_UPDATES_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    BUILD_PROPERTIES_FIELD_NUMBER: builtins.int
    ENTERPRISE_GRADE_CDN_STATUS_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    REPOSITORY_TOKEN_FIELD_NUMBER: builtins.int
    REPOSITORY_URL_FIELD_NUMBER: builtins.int
    STAGING_ENVIRONMENT_POLICY_FIELD_NUMBER: builtins.int
    TEMPLATE_PROPERTIES_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    STATIC_SITES_CONFIG_FIELD_NUMBER: builtins.int
    STATIC_SITES_CUSTOM_DOMAINS_FIELD_NUMBER: builtins.int
    STATIC_SITES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    STATIC_SITES_USER_PROVIDED_FUNCTION_APPS_FIELD_NUMBER: builtins.int
    STATIC_SITES_LINKED_BACKENDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    allow_config_file_updates: builtins.bool
    branch: builtins.str
    @property
    def build_properties(self) -> global___StaticSiteBuildProperties: ...
    enterprise_grade_cdn_status: builtins.str
    provider: builtins.str
    public_network_access: builtins.str
    repository_token: builtins.str
    repository_url: builtins.str
    staging_environment_policy: builtins.str
    @property
    def template_properties(self) -> global___StaticSiteTemplateOptions: ...
    @property
    def sku(self) -> global___SkuDescription: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def static_sites_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticSitesConfig]: ...
    @property
    def static_sites_custom_domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticSitesCustomDomains]: ...
    @property
    def static_sites_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticSitesPrivateEndpointConnections]: ...
    @property
    def static_sites_user_provided_function_apps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticSitesUserProvidedFunctionApps]: ...
    @property
    def static_sites_linked_backends(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticSitesLinkedBackends]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        allow_config_file_updates: builtins.bool = ...,
        branch: builtins.str = ...,
        build_properties: global___StaticSiteBuildProperties | None = ...,
        enterprise_grade_cdn_status: builtins.str = ...,
        provider: builtins.str = ...,
        public_network_access: builtins.str = ...,
        repository_token: builtins.str = ...,
        repository_url: builtins.str = ...,
        staging_environment_policy: builtins.str = ...,
        template_properties: global___StaticSiteTemplateOptions | None = ...,
        sku: global___SkuDescription | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        static_sites_config: collections.abc.Iterable[global___StaticSitesConfig] | None = ...,
        static_sites_custom_domains: collections.abc.Iterable[global___StaticSitesCustomDomains] | None = ...,
        static_sites_private_endpoint_connections: collections.abc.Iterable[global___StaticSitesPrivateEndpointConnections] | None = ...,
        static_sites_user_provided_function_apps: collections.abc.Iterable[global___StaticSitesUserProvidedFunctionApps] | None = ...,
        static_sites_linked_backends: collections.abc.Iterable[global___StaticSitesLinkedBackends] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_properties", b"build_properties", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku", "template_properties", b"template_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_config_file_updates", b"allow_config_file_updates", "branch", b"branch", "build_properties", b"build_properties", "enterprise_grade_cdn_status", b"enterprise_grade_cdn_status", "identity", b"identity", "kind", b"kind", "location", b"location", "name", b"name", "provider", b"provider", "public_network_access", b"public_network_access", "repository_token", b"repository_token", "repository_url", b"repository_url", "resource_info", b"resource_info", "sku", b"sku", "staging_environment_policy", b"staging_environment_policy", "static_sites_config", b"static_sites_config", "static_sites_custom_domains", b"static_sites_custom_domains", "static_sites_linked_backends", b"static_sites_linked_backends", "static_sites_private_endpoint_connections", b"static_sites_private_endpoint_connections", "static_sites_user_provided_function_apps", b"static_sites_user_provided_function_apps", "tags", b"tags", "template_properties", b"template_properties"]) -> None: ...

global___StaticSites = StaticSites

@typing_extensions.final
class StaticSiteTemplateOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    IS_PRIVATE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    TEMPLATE_REPOSITORY_URL_FIELD_NUMBER: builtins.int
    description: builtins.str
    is_private: builtins.bool
    owner: builtins.str
    repository_name: builtins.str
    template_repository_url: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        is_private: builtins.bool = ...,
        owner: builtins.str = ...,
        repository_name: builtins.str = ...,
        template_repository_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "is_private", b"is_private", "owner", b"owner", "repository_name", b"repository_name", "template_repository_url", b"template_repository_url"]) -> None: ...

global___StaticSiteTemplateOptions = StaticSiteTemplateOptions

@typing_extensions.final
class StaticSiteBuildProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_BUILD_COMMAND_FIELD_NUMBER: builtins.int
    API_LOCATION_FIELD_NUMBER: builtins.int
    APP_ARTIFACT_LOCATION_FIELD_NUMBER: builtins.int
    APP_BUILD_COMMAND_FIELD_NUMBER: builtins.int
    APP_LOCATION_FIELD_NUMBER: builtins.int
    GITHUB_ACTION_SECRET_NAME_OVERRIDE_FIELD_NUMBER: builtins.int
    OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    SKIP_GITHUB_ACTION_WORKFLOW_GENERATION_FIELD_NUMBER: builtins.int
    api_build_command: builtins.str
    api_location: builtins.str
    app_artifact_location: builtins.str
    app_build_command: builtins.str
    app_location: builtins.str
    github_action_secret_name_override: builtins.str
    output_location: builtins.str
    skip_github_action_workflow_generation: builtins.bool
    def __init__(
        self,
        *,
        api_build_command: builtins.str = ...,
        api_location: builtins.str = ...,
        app_artifact_location: builtins.str = ...,
        app_build_command: builtins.str = ...,
        app_location: builtins.str = ...,
        github_action_secret_name_override: builtins.str = ...,
        output_location: builtins.str = ...,
        skip_github_action_workflow_generation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_build_command", b"api_build_command", "api_location", b"api_location", "app_artifact_location", b"app_artifact_location", "app_build_command", b"app_build_command", "app_location", b"app_location", "github_action_secret_name_override", b"github_action_secret_name_override", "output_location", b"output_location", "skip_github_action_workflow_generation", b"skip_github_action_workflow_generation"]) -> None: ...

global___StaticSiteBuildProperties = StaticSiteBuildProperties

@typing_extensions.final
class SitesVirtualNetworkConnectionsGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VNET_NAME_FIELD_NUMBER: builtins.int
    VPN_PACKAGE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    vnet_name: builtins.str
    vpn_package_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        vnet_name: builtins.str = ...,
        vpn_package_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "resource_info", b"resource_info", "vnet_name", b"vnet_name", "vpn_package_uri", b"vpn_package_uri"]) -> None: ...

global___SitesVirtualNetworkConnectionsGateways = SitesVirtualNetworkConnectionsGateways

@typing_extensions.final
class SitesVirtualNetworkConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CERT_BLOB_FIELD_NUMBER: builtins.int
    DNS_SERVERS_FIELD_NUMBER: builtins.int
    IS_SWIFT_FIELD_NUMBER: builtins.int
    VNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    SITES_VIRTUAL_NETWORK_CONNECTIONS_GATEWAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    cert_blob: builtins.str
    dns_servers: builtins.str
    is_swift: builtins.bool
    vnet_resource_id: builtins.str
    @property
    def sites_virtual_network_connections_gateways(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesVirtualNetworkConnectionsGateways]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        cert_blob: builtins.str = ...,
        dns_servers: builtins.str = ...,
        is_swift: builtins.bool = ...,
        vnet_resource_id: builtins.str = ...,
        sites_virtual_network_connections_gateways: collections.abc.Iterable[global___SitesVirtualNetworkConnectionsGateways] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert_blob", b"cert_blob", "dns_servers", b"dns_servers", "is_swift", b"is_swift", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "sites_virtual_network_connections_gateways", b"sites_virtual_network_connections_gateways", "vnet_resource_id", b"vnet_resource_id"]) -> None: ...

global___SitesVirtualNetworkConnections = SitesVirtualNetworkConnections

@typing_extensions.final
class SitesSourcecontrols(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ROLLBACK_ENABLED_FIELD_NUMBER: builtins.int
    GIT_HUB_ACTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    IS_GIT_HUB_ACTION_FIELD_NUMBER: builtins.int
    IS_MANUAL_INTEGRATION_FIELD_NUMBER: builtins.int
    IS_MERCURIAL_FIELD_NUMBER: builtins.int
    REPO_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    branch: builtins.str
    deployment_rollback_enabled: builtins.bool
    @property
    def git_hub_action_configuration(self) -> global___GitHubActionConfiguration: ...
    is_git_hub_action: builtins.bool
    is_manual_integration: builtins.bool
    is_mercurial: builtins.bool
    repo_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        branch: builtins.str = ...,
        deployment_rollback_enabled: builtins.bool = ...,
        git_hub_action_configuration: global___GitHubActionConfiguration | None = ...,
        is_git_hub_action: builtins.bool = ...,
        is_manual_integration: builtins.bool = ...,
        is_mercurial: builtins.bool = ...,
        repo_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_hub_action_configuration", b"git_hub_action_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "deployment_rollback_enabled", b"deployment_rollback_enabled", "git_hub_action_configuration", b"git_hub_action_configuration", "is_git_hub_action", b"is_git_hub_action", "is_manual_integration", b"is_manual_integration", "is_mercurial", b"is_mercurial", "kind", b"kind", "name", b"name", "repo_url", b"repo_url", "resource_info", b"resource_info"]) -> None: ...

global___SitesSourcecontrols = SitesSourcecontrols

@typing_extensions.final
class SitesSlotsVirtualNetworkConnectionsGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VNET_NAME_FIELD_NUMBER: builtins.int
    VPN_PACKAGE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    vnet_name: builtins.str
    vpn_package_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        vnet_name: builtins.str = ...,
        vpn_package_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "resource_info", b"resource_info", "vnet_name", b"vnet_name", "vpn_package_uri", b"vpn_package_uri"]) -> None: ...

global___SitesSlotsVirtualNetworkConnectionsGateways = SitesSlotsVirtualNetworkConnectionsGateways

@typing_extensions.final
class SitesSlotsVirtualNetworkConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CERT_BLOB_FIELD_NUMBER: builtins.int
    DNS_SERVERS_FIELD_NUMBER: builtins.int
    IS_SWIFT_FIELD_NUMBER: builtins.int
    VNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    SITES_SLOTS_VIRTUAL_NETWORK_CONNECTIONS_GATEWAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    cert_blob: builtins.str
    dns_servers: builtins.str
    is_swift: builtins.bool
    vnet_resource_id: builtins.str
    @property
    def sites_slots_virtual_network_connections_gateways(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsVirtualNetworkConnectionsGateways]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        cert_blob: builtins.str = ...,
        dns_servers: builtins.str = ...,
        is_swift: builtins.bool = ...,
        vnet_resource_id: builtins.str = ...,
        sites_slots_virtual_network_connections_gateways: collections.abc.Iterable[global___SitesSlotsVirtualNetworkConnectionsGateways] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert_blob", b"cert_blob", "dns_servers", b"dns_servers", "is_swift", b"is_swift", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "sites_slots_virtual_network_connections_gateways", b"sites_slots_virtual_network_connections_gateways", "vnet_resource_id", b"vnet_resource_id"]) -> None: ...

global___SitesSlotsVirtualNetworkConnections = SitesSlotsVirtualNetworkConnections

@typing_extensions.final
class SitesSlotsSourcecontrols(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ROLLBACK_ENABLED_FIELD_NUMBER: builtins.int
    GIT_HUB_ACTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    IS_GIT_HUB_ACTION_FIELD_NUMBER: builtins.int
    IS_MANUAL_INTEGRATION_FIELD_NUMBER: builtins.int
    IS_MERCURIAL_FIELD_NUMBER: builtins.int
    REPO_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    branch: builtins.str
    deployment_rollback_enabled: builtins.bool
    @property
    def git_hub_action_configuration(self) -> global___GitHubActionConfiguration: ...
    is_git_hub_action: builtins.bool
    is_manual_integration: builtins.bool
    is_mercurial: builtins.bool
    repo_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        branch: builtins.str = ...,
        deployment_rollback_enabled: builtins.bool = ...,
        git_hub_action_configuration: global___GitHubActionConfiguration | None = ...,
        is_git_hub_action: builtins.bool = ...,
        is_manual_integration: builtins.bool = ...,
        is_mercurial: builtins.bool = ...,
        repo_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_hub_action_configuration", b"git_hub_action_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "deployment_rollback_enabled", b"deployment_rollback_enabled", "git_hub_action_configuration", b"git_hub_action_configuration", "is_git_hub_action", b"is_git_hub_action", "is_manual_integration", b"is_manual_integration", "is_mercurial", b"is_mercurial", "kind", b"kind", "name", b"name", "repo_url", b"repo_url", "resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsSourcecontrols = SitesSlotsSourcecontrols

@typing_extensions.final
class GitHubActionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_CONFIGURATION_FIELD_NUMBER: builtins.int
    CONTAINER_CONFIGURATION_FIELD_NUMBER: builtins.int
    GENERATE_WORKFLOW_FILE_FIELD_NUMBER: builtins.int
    IS_LINUX_FIELD_NUMBER: builtins.int
    @property
    def code_configuration(self) -> global___GitHubActionCodeConfiguration: ...
    @property
    def container_configuration(self) -> global___GitHubActionContainerConfiguration: ...
    generate_workflow_file: builtins.bool
    is_linux: builtins.bool
    def __init__(
        self,
        *,
        code_configuration: global___GitHubActionCodeConfiguration | None = ...,
        container_configuration: global___GitHubActionContainerConfiguration | None = ...,
        generate_workflow_file: builtins.bool = ...,
        is_linux: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["code_configuration", b"code_configuration", "container_configuration", b"container_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_configuration", b"code_configuration", "container_configuration", b"container_configuration", "generate_workflow_file", b"generate_workflow_file", "is_linux", b"is_linux"]) -> None: ...

global___GitHubActionConfiguration = GitHubActionConfiguration

@typing_extensions.final
class GitHubActionContainerConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SERVER_URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    image_name: builtins.str
    password: builtins.str
    server_url: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        image_name: builtins.str = ...,
        password: builtins.str = ...,
        server_url: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_name", b"image_name", "password", b"password", "server_url", b"server_url", "username", b"username"]) -> None: ...

global___GitHubActionContainerConfiguration = GitHubActionContainerConfiguration

@typing_extensions.final
class GitHubActionCodeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_STACK_FIELD_NUMBER: builtins.int
    RUNTIME_VERSION_FIELD_NUMBER: builtins.int
    runtime_stack: builtins.str
    runtime_version: builtins.str
    def __init__(
        self,
        *,
        runtime_stack: builtins.str = ...,
        runtime_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_stack", b"runtime_stack", "runtime_version", b"runtime_version"]) -> None: ...

global___GitHubActionCodeConfiguration = GitHubActionCodeConfiguration

@typing_extensions.final
class SitesSlotsSiteextensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsSiteextensions = SitesSlotsSiteextensions

@typing_extensions.final
class SitesSlotsPublicCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BLOB_FIELD_NUMBER: builtins.int
    PUBLIC_CERTIFICATE_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    blob: builtins.str
    public_certificate_location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        blob: builtins.str = ...,
        public_certificate_location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "kind", b"kind", "name", b"name", "public_certificate_location", b"public_certificate_location", "resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsPublicCertificates = SitesSlotsPublicCertificates

@typing_extensions.final
class SitesSlotsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsPrivateEndpointConnections = SitesSlotsPrivateEndpointConnections

@typing_extensions.final
class SitesSlotsPrivateAccess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORKS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    enabled: builtins.bool
    @property
    def virtual_networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateAccessVirtualNetwork]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        enabled: builtins.bool = ...,
        virtual_networks: collections.abc.Iterable[global___PrivateAccessVirtualNetwork] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "virtual_networks", b"virtual_networks"]) -> None: ...

global___SitesSlotsPrivateAccess = SitesSlotsPrivateAccess

@typing_extensions.final
class SitesSlotsPremieraddons(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MARKETPLACE_OFFER_FIELD_NUMBER: builtins.int
    MARKETPLACE_PUBLISHER_FIELD_NUMBER: builtins.int
    PRODUCT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    marketplace_offer: builtins.str
    marketplace_publisher: builtins.str
    product: builtins.str
    sku: builtins.str
    vendor: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        marketplace_offer: builtins.str = ...,
        marketplace_publisher: builtins.str = ...,
        product: builtins.str = ...,
        sku: builtins.str = ...,
        vendor: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "location", b"location", "marketplace_offer", b"marketplace_offer", "marketplace_publisher", b"marketplace_publisher", "name", b"name", "product", b"product", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "vendor", b"vendor"]) -> None: ...

global___SitesSlotsPremieraddons = SitesSlotsPremieraddons

@typing_extensions.final
class SitesSlotsNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SUBNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    SWIFT_SUPPORTED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    subnet_resource_id: builtins.str
    swift_supported: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        subnet_resource_id: builtins.str = ...,
        swift_supported: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "resource_info", b"resource_info", "subnet_resource_id", b"subnet_resource_id", "swift_supported", b"swift_supported"]) -> None: ...

global___SitesSlotsNetworkConfig = SitesSlotsNetworkConfig

@typing_extensions.final
class SitesSlotsInstancesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SetParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    APP_OFFLINE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    DB_TYPE_FIELD_NUMBER: builtins.int
    PACKAGE_URI_FIELD_NUMBER: builtins.int
    SET_PARAMETERS_FIELD_NUMBER: builtins.int
    SET_PARAMETERS_XML_FILE_URI_FIELD_NUMBER: builtins.int
    SKIP_APP_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    app_offline: builtins.bool
    connection_string: builtins.str
    db_type: builtins.str
    package_uri: builtins.str
    @property
    def set_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    set_parameters_xml_file_uri: builtins.str
    skip_app_data: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        app_offline: builtins.bool = ...,
        connection_string: builtins.str = ...,
        db_type: builtins.str = ...,
        package_uri: builtins.str = ...,
        set_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        set_parameters_xml_file_uri: builtins.str = ...,
        skip_app_data: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_offline", b"app_offline", "connection_string", b"connection_string", "db_type", b"db_type", "kind", b"kind", "name", b"name", "package_uri", b"package_uri", "resource_info", b"resource_info", "set_parameters", b"set_parameters", "set_parameters_xml_file_uri", b"set_parameters_xml_file_uri", "skip_app_data", b"skip_app_data"]) -> None: ...

global___SitesSlotsInstancesExtensions = SitesSlotsInstancesExtensions

@typing_extensions.final
class SitesSlotsHybridConnectionNamespacesRelays(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RELAY_ARM_URI_FIELD_NUMBER: builtins.int
    RELAY_NAME_FIELD_NUMBER: builtins.int
    SEND_KEY_NAME_FIELD_NUMBER: builtins.int
    SEND_KEY_VALUE_FIELD_NUMBER: builtins.int
    SERVICE_BUS_NAMESPACE_FIELD_NUMBER: builtins.int
    SERVICE_BUS_SUFFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    hostname: builtins.str
    port: builtins.int
    relay_arm_uri: builtins.str
    relay_name: builtins.str
    send_key_name: builtins.str
    send_key_value: builtins.str
    service_bus_namespace: builtins.str
    service_bus_suffix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        hostname: builtins.str = ...,
        port: builtins.int = ...,
        relay_arm_uri: builtins.str = ...,
        relay_name: builtins.str = ...,
        send_key_name: builtins.str = ...,
        send_key_value: builtins.str = ...,
        service_bus_namespace: builtins.str = ...,
        service_bus_suffix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostname", b"hostname", "kind", b"kind", "name", b"name", "port", b"port", "relay_arm_uri", b"relay_arm_uri", "relay_name", b"relay_name", "resource_info", b"resource_info", "send_key_name", b"send_key_name", "send_key_value", b"send_key_value", "service_bus_namespace", b"service_bus_namespace", "service_bus_suffix", b"service_bus_suffix"]) -> None: ...

global___SitesSlotsHybridConnectionNamespacesRelays = SitesSlotsHybridConnectionNamespacesRelays

@typing_extensions.final
class SitesSlotsHybridconnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BIZTALK_URI_FIELD_NUMBER: builtins.int
    ENTITY_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENTITY_NAME_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    biztalk_uri: builtins.str
    entity_connection_string: builtins.str
    entity_name: builtins.str
    hostname: builtins.str
    port: builtins.int
    resource_connection_string: builtins.str
    resource_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        biztalk_uri: builtins.str = ...,
        entity_connection_string: builtins.str = ...,
        entity_name: builtins.str = ...,
        hostname: builtins.str = ...,
        port: builtins.int = ...,
        resource_connection_string: builtins.str = ...,
        resource_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biztalk_uri", b"biztalk_uri", "entity_connection_string", b"entity_connection_string", "entity_name", b"entity_name", "hostname", b"hostname", "kind", b"kind", "name", b"name", "port", b"port", "resource_connection_string", b"resource_connection_string", "resource_info", b"resource_info", "resource_type", b"resource_type"]) -> None: ...

global___SitesSlotsHybridconnection = SitesSlotsHybridconnection

@typing_extensions.final
class SitesSlotsHostNameBindings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    AZURE_RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    CUSTOM_HOST_NAME_DNS_RECORD_TYPE_FIELD_NUMBER: builtins.int
    DOMAIN_ID_FIELD_NUMBER: builtins.int
    HOST_NAME_TYPE_FIELD_NUMBER: builtins.int
    SITE_NAME_FIELD_NUMBER: builtins.int
    SSL_STATE_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    azure_resource_name: builtins.str
    azure_resource_type: builtins.str
    custom_host_name_dns_record_type: builtins.str
    domain_id: builtins.str
    host_name_type: builtins.str
    site_name: builtins.str
    ssl_state: builtins.str
    thumbprint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        azure_resource_name: builtins.str = ...,
        azure_resource_type: builtins.str = ...,
        custom_host_name_dns_record_type: builtins.str = ...,
        domain_id: builtins.str = ...,
        host_name_type: builtins.str = ...,
        site_name: builtins.str = ...,
        ssl_state: builtins.str = ...,
        thumbprint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_resource_name", b"azure_resource_name", "azure_resource_type", b"azure_resource_type", "custom_host_name_dns_record_type", b"custom_host_name_dns_record_type", "domain_id", b"domain_id", "host_name_type", b"host_name_type", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "site_name", b"site_name", "ssl_state", b"ssl_state", "thumbprint", b"thumbprint"]) -> None: ...

global___SitesSlotsHostNameBindings = SitesSlotsHostNameBindings

@typing_extensions.final
class SitesSlotsFunctionsKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___SitesSlotsFunctionsKeys = SitesSlotsFunctionsKeys

@typing_extensions.final
class SitesSlotsFunctions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class FilesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    CONFIG_HREF_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    FUNCTION_APP_ID_FIELD_NUMBER: builtins.int
    HREF_FIELD_NUMBER: builtins.int
    INVOKE_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    IS_DISABLED_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    SCRIPT_HREF_FIELD_NUMBER: builtins.int
    SCRIPT_ROOT_PATH_HREF_FIELD_NUMBER: builtins.int
    SECRETS_FILE_HREF_FIELD_NUMBER: builtins.int
    TEST_DATA_FIELD_NUMBER: builtins.int
    TEST_DATA_HREF_FIELD_NUMBER: builtins.int
    SITES_SLOTS_FUNCTIONS_KEYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    @property
    def config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    config_href: builtins.str
    @property
    def files(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    function_app_id: builtins.str
    href: builtins.str
    invoke_url_template: builtins.str
    is_disabled: builtins.bool
    language: builtins.str
    script_href: builtins.str
    script_root_path_href: builtins.str
    secrets_file_href: builtins.str
    test_data: builtins.str
    test_data_href: builtins.str
    @property
    def sites_slots_functions_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsFunctionsKeys]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_href: builtins.str = ...,
        files: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        function_app_id: builtins.str = ...,
        href: builtins.str = ...,
        invoke_url_template: builtins.str = ...,
        is_disabled: builtins.bool = ...,
        language: builtins.str = ...,
        script_href: builtins.str = ...,
        script_root_path_href: builtins.str = ...,
        secrets_file_href: builtins.str = ...,
        test_data: builtins.str = ...,
        test_data_href: builtins.str = ...,
        sites_slots_functions_keys: collections.abc.Iterable[global___SitesSlotsFunctionsKeys] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "config_href", b"config_href", "files", b"files", "function_app_id", b"function_app_id", "href", b"href", "invoke_url_template", b"invoke_url_template", "is_disabled", b"is_disabled", "kind", b"kind", "language", b"language", "name", b"name", "resource_info", b"resource_info", "script_href", b"script_href", "script_root_path_href", b"script_root_path_href", "secrets_file_href", b"secrets_file_href", "sites_slots_functions_keys", b"sites_slots_functions_keys", "test_data", b"test_data", "test_data_href", b"test_data_href"]) -> None: ...

global___SitesSlotsFunctions = SitesSlotsFunctions

@typing_extensions.final
class SitesSlotsExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SetParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    APP_OFFLINE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    DB_TYPE_FIELD_NUMBER: builtins.int
    PACKAGE_URI_FIELD_NUMBER: builtins.int
    SET_PARAMETERS_FIELD_NUMBER: builtins.int
    SET_PARAMETERS_XML_FILE_URI_FIELD_NUMBER: builtins.int
    SKIP_APP_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    app_offline: builtins.bool
    connection_string: builtins.str
    db_type: builtins.str
    package_uri: builtins.str
    @property
    def set_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    set_parameters_xml_file_uri: builtins.str
    skip_app_data: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        app_offline: builtins.bool = ...,
        connection_string: builtins.str = ...,
        db_type: builtins.str = ...,
        package_uri: builtins.str = ...,
        set_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        set_parameters_xml_file_uri: builtins.str = ...,
        skip_app_data: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_offline", b"app_offline", "connection_string", b"connection_string", "db_type", b"db_type", "kind", b"kind", "name", b"name", "package_uri", b"package_uri", "resource_info", b"resource_info", "set_parameters", b"set_parameters", "set_parameters_xml_file_uri", b"set_parameters_xml_file_uri", "skip_app_data", b"skip_app_data"]) -> None: ...

global___SitesSlotsExtensions = SitesSlotsExtensions

@typing_extensions.final
class SitesSlotsDomainOwnershipIdentifiers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsDomainOwnershipIdentifiers = SitesSlotsDomainOwnershipIdentifiers

@typing_extensions.final
class SitesSlotsDeployments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_EMAIL_FIELD_NUMBER: builtins.int
    DEPLOYER_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    active: builtins.bool
    author: builtins.str
    author_email: builtins.str
    deployer: builtins.str
    details: builtins.str
    end_time: builtins.str
    message: builtins.str
    start_time: builtins.str
    status: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        active: builtins.bool = ...,
        author: builtins.str = ...,
        author_email: builtins.str = ...,
        deployer: builtins.str = ...,
        details: builtins.str = ...,
        end_time: builtins.str = ...,
        message: builtins.str = ...,
        start_time: builtins.str = ...,
        status: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "author", b"author", "author_email", b"author_email", "deployer", b"deployer", "details", b"details", "end_time", b"end_time", "kind", b"kind", "message", b"message", "name", b"name", "resource_info", b"resource_info", "start_time", b"start_time", "status", b"status"]) -> None: ...

global___SitesSlotsDeployments = SitesSlotsDeployments

@typing_extensions.final
class SitesSlotsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsConfig = SitesSlotsConfig

@typing_extensions.final
class SitesSlotsBasicPublishingCredentialsPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___SitesSlotsBasicPublishingCredentialsPolicies = SitesSlotsBasicPublishingCredentialsPolicies

@typing_extensions.final
class SitesSlots(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLIENT_AFFINITY_ENABLED_FIELD_NUMBER: builtins.int
    CLIENT_CERT_ENABLED_FIELD_NUMBER: builtins.int
    CLIENT_CERT_EXCLUSION_PATHS_FIELD_NUMBER: builtins.int
    CLIENT_CERT_MODE_FIELD_NUMBER: builtins.int
    CLONING_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_SIZE_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_VERIFICATION_ID_FIELD_NUMBER: builtins.int
    DAILY_MEMORY_TIME_QUOTA_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENT_PROFILE_FIELD_NUMBER: builtins.int
    HOST_NAMES_DISABLED_FIELD_NUMBER: builtins.int
    HOST_NAME_SSL_STATES_FIELD_NUMBER: builtins.int
    HTTPS_ONLY_FIELD_NUMBER: builtins.int
    HYPER_V_FIELD_NUMBER: builtins.int
    IS_XENON_FIELD_NUMBER: builtins.int
    KEY_VAULT_REFERENCE_IDENTITY_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    REDUNDANCY_MODE_FIELD_NUMBER: builtins.int
    RESERVED_FIELD_NUMBER: builtins.int
    SCM_SITE_ALSO_STOPPED_FIELD_NUMBER: builtins.int
    SERVER_FARM_ID_FIELD_NUMBER: builtins.int
    SITE_CONFIG_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_REQUIRED_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_SUBNET_ID_FIELD_NUMBER: builtins.int
    VNET_CONTENT_SHARE_ENABLED_FIELD_NUMBER: builtins.int
    VNET_IMAGE_PULL_ENABLED_FIELD_NUMBER: builtins.int
    VNET_ROUTE_ALL_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_BASIC_PUBLISHING_CREDENTIALS_POLICIES_FIELD_NUMBER: builtins.int
    SITES_SLOTS_CONFIG_FIELD_NUMBER: builtins.int
    SITES_SLOTS_DEPLOYMENTS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_DOMAIN_OWNERSHIP_IDENTIFIERS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_EXTENSIONS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_FUNCTIONS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_HOST_NAME_BINDINGS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_HYBRIDCONNECTION_FIELD_NUMBER: builtins.int
    SITES_SLOTS_NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    SITES_SLOTS_PREMIERADDONS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_PRIVATE_ACCESS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_PUBLIC_CERTIFICATES_FIELD_NUMBER: builtins.int
    SITES_SLOTS_SITEEXTENSIONS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_SOURCECONTROLS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_VIRTUAL_NETWORK_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    client_affinity_enabled: builtins.bool
    client_cert_enabled: builtins.bool
    client_cert_exclusion_paths: builtins.str
    client_cert_mode: builtins.str
    @property
    def cloning_info(self) -> global___CloningInfo: ...
    container_size: builtins.int
    custom_domain_verification_id: builtins.str
    daily_memory_time_quota: builtins.int
    enabled: builtins.bool
    @property
    def hosting_environment_profile(self) -> global___HostingEnvironmentProfile: ...
    host_names_disabled: builtins.bool
    @property
    def host_name_ssl_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostNameSslState]: ...
    https_only: builtins.bool
    hyper_v: builtins.bool
    is_xenon: builtins.bool
    key_vault_reference_identity: builtins.str
    public_network_access: builtins.str
    redundancy_mode: builtins.str
    reserved: builtins.bool
    scm_site_also_stopped: builtins.bool
    server_farm_id: builtins.str
    @property
    def site_config(self) -> global___SiteConfig: ...
    storage_account_required: builtins.bool
    virtual_network_subnet_id: builtins.str
    vnet_content_share_enabled: builtins.bool
    vnet_image_pull_enabled: builtins.bool
    vnet_route_all_enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sites_slots_basic_publishing_credentials_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsBasicPublishingCredentialsPolicies]: ...
    @property
    def sites_slots_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsConfig]: ...
    @property
    def sites_slots_deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsDeployments]: ...
    @property
    def sites_slots_domain_ownership_identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsDomainOwnershipIdentifiers]: ...
    @property
    def sites_slots_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsExtensions]: ...
    @property
    def sites_slots_functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsFunctions]: ...
    @property
    def sites_slots_host_name_bindings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsHostNameBindings]: ...
    @property
    def sites_slots_hybridconnection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsHybridconnection]: ...
    @property
    def sites_slots_network_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsNetworkConfig]: ...
    @property
    def sites_slots_premieraddons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsPremieraddons]: ...
    @property
    def sites_slots_private_access(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsPrivateAccess]: ...
    @property
    def sites_slots_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsPrivateEndpointConnections]: ...
    @property
    def sites_slots_public_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsPublicCertificates]: ...
    @property
    def sites_slots_siteextensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsSiteextensions]: ...
    @property
    def sites_slots_sourcecontrols(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsSourcecontrols]: ...
    @property
    def sites_slots_virtual_network_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlotsVirtualNetworkConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        client_affinity_enabled: builtins.bool = ...,
        client_cert_enabled: builtins.bool = ...,
        client_cert_exclusion_paths: builtins.str = ...,
        client_cert_mode: builtins.str = ...,
        cloning_info: global___CloningInfo | None = ...,
        container_size: builtins.int = ...,
        custom_domain_verification_id: builtins.str = ...,
        daily_memory_time_quota: builtins.int = ...,
        enabled: builtins.bool = ...,
        hosting_environment_profile: global___HostingEnvironmentProfile | None = ...,
        host_names_disabled: builtins.bool = ...,
        host_name_ssl_states: collections.abc.Iterable[global___HostNameSslState] | None = ...,
        https_only: builtins.bool = ...,
        hyper_v: builtins.bool = ...,
        is_xenon: builtins.bool = ...,
        key_vault_reference_identity: builtins.str = ...,
        public_network_access: builtins.str = ...,
        redundancy_mode: builtins.str = ...,
        reserved: builtins.bool = ...,
        scm_site_also_stopped: builtins.bool = ...,
        server_farm_id: builtins.str = ...,
        site_config: global___SiteConfig | None = ...,
        storage_account_required: builtins.bool = ...,
        virtual_network_subnet_id: builtins.str = ...,
        vnet_content_share_enabled: builtins.bool = ...,
        vnet_image_pull_enabled: builtins.bool = ...,
        vnet_route_all_enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sites_slots_basic_publishing_credentials_policies: collections.abc.Iterable[global___SitesSlotsBasicPublishingCredentialsPolicies] | None = ...,
        sites_slots_config: collections.abc.Iterable[global___SitesSlotsConfig] | None = ...,
        sites_slots_deployments: collections.abc.Iterable[global___SitesSlotsDeployments] | None = ...,
        sites_slots_domain_ownership_identifiers: collections.abc.Iterable[global___SitesSlotsDomainOwnershipIdentifiers] | None = ...,
        sites_slots_extensions: collections.abc.Iterable[global___SitesSlotsExtensions] | None = ...,
        sites_slots_functions: collections.abc.Iterable[global___SitesSlotsFunctions] | None = ...,
        sites_slots_host_name_bindings: collections.abc.Iterable[global___SitesSlotsHostNameBindings] | None = ...,
        sites_slots_hybridconnection: collections.abc.Iterable[global___SitesSlotsHybridconnection] | None = ...,
        sites_slots_network_config: collections.abc.Iterable[global___SitesSlotsNetworkConfig] | None = ...,
        sites_slots_premieraddons: collections.abc.Iterable[global___SitesSlotsPremieraddons] | None = ...,
        sites_slots_private_access: collections.abc.Iterable[global___SitesSlotsPrivateAccess] | None = ...,
        sites_slots_private_endpoint_connections: collections.abc.Iterable[global___SitesSlotsPrivateEndpointConnections] | None = ...,
        sites_slots_public_certificates: collections.abc.Iterable[global___SitesSlotsPublicCertificates] | None = ...,
        sites_slots_siteextensions: collections.abc.Iterable[global___SitesSlotsSiteextensions] | None = ...,
        sites_slots_sourcecontrols: collections.abc.Iterable[global___SitesSlotsSourcecontrols] | None = ...,
        sites_slots_virtual_network_connections: collections.abc.Iterable[global___SitesSlotsVirtualNetworkConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloning_info", b"cloning_info", "extended_location", b"extended_location", "hosting_environment_profile", b"hosting_environment_profile", "identity", b"identity", "resource_info", b"resource_info", "site_config", b"site_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_affinity_enabled", b"client_affinity_enabled", "client_cert_enabled", b"client_cert_enabled", "client_cert_exclusion_paths", b"client_cert_exclusion_paths", "client_cert_mode", b"client_cert_mode", "cloning_info", b"cloning_info", "container_size", b"container_size", "custom_domain_verification_id", b"custom_domain_verification_id", "daily_memory_time_quota", b"daily_memory_time_quota", "enabled", b"enabled", "extended_location", b"extended_location", "host_name_ssl_states", b"host_name_ssl_states", "host_names_disabled", b"host_names_disabled", "hosting_environment_profile", b"hosting_environment_profile", "https_only", b"https_only", "hyper_v", b"hyper_v", "identity", b"identity", "is_xenon", b"is_xenon", "key_vault_reference_identity", b"key_vault_reference_identity", "kind", b"kind", "location", b"location", "name", b"name", "public_network_access", b"public_network_access", "redundancy_mode", b"redundancy_mode", "reserved", b"reserved", "resource_info", b"resource_info", "scm_site_also_stopped", b"scm_site_also_stopped", "server_farm_id", b"server_farm_id", "site_config", b"site_config", "sites_slots_basic_publishing_credentials_policies", b"sites_slots_basic_publishing_credentials_policies", "sites_slots_config", b"sites_slots_config", "sites_slots_deployments", b"sites_slots_deployments", "sites_slots_domain_ownership_identifiers", b"sites_slots_domain_ownership_identifiers", "sites_slots_extensions", b"sites_slots_extensions", "sites_slots_functions", b"sites_slots_functions", "sites_slots_host_name_bindings", b"sites_slots_host_name_bindings", "sites_slots_hybridconnection", b"sites_slots_hybridconnection", "sites_slots_network_config", b"sites_slots_network_config", "sites_slots_premieraddons", b"sites_slots_premieraddons", "sites_slots_private_access", b"sites_slots_private_access", "sites_slots_private_endpoint_connections", b"sites_slots_private_endpoint_connections", "sites_slots_public_certificates", b"sites_slots_public_certificates", "sites_slots_siteextensions", b"sites_slots_siteextensions", "sites_slots_sourcecontrols", b"sites_slots_sourcecontrols", "sites_slots_virtual_network_connections", b"sites_slots_virtual_network_connections", "storage_account_required", b"storage_account_required", "tags", b"tags", "virtual_network_subnet_id", b"virtual_network_subnet_id", "vnet_content_share_enabled", b"vnet_content_share_enabled", "vnet_image_pull_enabled", b"vnet_image_pull_enabled", "vnet_route_all_enabled", b"vnet_route_all_enabled"]) -> None: ...

global___SitesSlots = SitesSlots

@typing_extensions.final
class SitesSiteextensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___SitesSiteextensions = SitesSiteextensions

@typing_extensions.final
class SitesPublicCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BLOB_FIELD_NUMBER: builtins.int
    PUBLIC_CERTIFICATE_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    blob: builtins.str
    public_certificate_location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        blob: builtins.str = ...,
        public_certificate_location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "kind", b"kind", "name", b"name", "public_certificate_location", b"public_certificate_location", "resource_info", b"resource_info"]) -> None: ...

global___SitesPublicCertificates = SitesPublicCertificates

@typing_extensions.final
class SitesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___SitesPrivateEndpointConnections = SitesPrivateEndpointConnections

@typing_extensions.final
class SitesPrivateAccess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORKS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    enabled: builtins.bool
    @property
    def virtual_networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateAccessVirtualNetwork]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        enabled: builtins.bool = ...,
        virtual_networks: collections.abc.Iterable[global___PrivateAccessVirtualNetwork] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "virtual_networks", b"virtual_networks"]) -> None: ...

global___SitesPrivateAccess = SitesPrivateAccess

@typing_extensions.final
class PrivateAccessVirtualNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    key: builtins.int
    name: builtins.str
    resource_id: builtins.str
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateAccessSubnet]: ...
    def __init__(
        self,
        *,
        key: builtins.int = ...,
        name: builtins.str = ...,
        resource_id: builtins.str = ...,
        subnets: collections.abc.Iterable[global___PrivateAccessSubnet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name", "resource_id", b"resource_id", "subnets", b"subnets"]) -> None: ...

global___PrivateAccessVirtualNetwork = PrivateAccessVirtualNetwork

@typing_extensions.final
class PrivateAccessSubnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    key: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        key: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name"]) -> None: ...

global___PrivateAccessSubnet = PrivateAccessSubnet

@typing_extensions.final
class SitesPremieraddons(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MARKETPLACE_OFFER_FIELD_NUMBER: builtins.int
    MARKETPLACE_PUBLISHER_FIELD_NUMBER: builtins.int
    PRODUCT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    marketplace_offer: builtins.str
    marketplace_publisher: builtins.str
    product: builtins.str
    sku: builtins.str
    vendor: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        marketplace_offer: builtins.str = ...,
        marketplace_publisher: builtins.str = ...,
        product: builtins.str = ...,
        sku: builtins.str = ...,
        vendor: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "location", b"location", "marketplace_offer", b"marketplace_offer", "marketplace_publisher", b"marketplace_publisher", "name", b"name", "product", b"product", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "vendor", b"vendor"]) -> None: ...

global___SitesPremieraddons = SitesPremieraddons

@typing_extensions.final
class SitesNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SUBNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    SWIFT_SUPPORTED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    subnet_resource_id: builtins.str
    swift_supported: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        subnet_resource_id: builtins.str = ...,
        swift_supported: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "resource_info", b"resource_info", "subnet_resource_id", b"subnet_resource_id", "swift_supported", b"swift_supported"]) -> None: ...

global___SitesNetworkConfig = SitesNetworkConfig

@typing_extensions.final
class SitesMigrate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZUREFILES_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    AZUREFILES_SHARE_FIELD_NUMBER: builtins.int
    BLOCK_WRITE_ACCESS_TO_SITE_FIELD_NUMBER: builtins.int
    SWITCH_SITE_AFTER_MIGRATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    azurefiles_connection_string: builtins.str
    azurefiles_share: builtins.str
    block_write_access_to_site: builtins.bool
    switch_site_after_migration: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        azurefiles_connection_string: builtins.str = ...,
        azurefiles_share: builtins.str = ...,
        block_write_access_to_site: builtins.bool = ...,
        switch_site_after_migration: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azurefiles_connection_string", b"azurefiles_connection_string", "azurefiles_share", b"azurefiles_share", "block_write_access_to_site", b"block_write_access_to_site", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "switch_site_after_migration", b"switch_site_after_migration"]) -> None: ...

global___SitesMigrate = SitesMigrate

@typing_extensions.final
class SitesInstancesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SetParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    APP_OFFLINE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    DB_TYPE_FIELD_NUMBER: builtins.int
    PACKAGE_URI_FIELD_NUMBER: builtins.int
    SET_PARAMETERS_FIELD_NUMBER: builtins.int
    SET_PARAMETERS_XML_FILE_URI_FIELD_NUMBER: builtins.int
    SKIP_APP_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    app_offline: builtins.bool
    connection_string: builtins.str
    db_type: builtins.str
    package_uri: builtins.str
    @property
    def set_parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    set_parameters_xml_file_uri: builtins.str
    skip_app_data: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        app_offline: builtins.bool = ...,
        connection_string: builtins.str = ...,
        db_type: builtins.str = ...,
        package_uri: builtins.str = ...,
        set_parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        set_parameters_xml_file_uri: builtins.str = ...,
        skip_app_data: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_offline", b"app_offline", "connection_string", b"connection_string", "db_type", b"db_type", "kind", b"kind", "name", b"name", "package_uri", b"package_uri", "resource_info", b"resource_info", "set_parameters", b"set_parameters", "set_parameters_xml_file_uri", b"set_parameters_xml_file_uri", "skip_app_data", b"skip_app_data"]) -> None: ...

global___SitesInstancesExtensions = SitesInstancesExtensions

@typing_extensions.final
class SitesHybridConnectionNamespacesRelays(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RELAY_ARM_URI_FIELD_NUMBER: builtins.int
    RELAY_NAME_FIELD_NUMBER: builtins.int
    SEND_KEY_NAME_FIELD_NUMBER: builtins.int
    SEND_KEY_VALUE_FIELD_NUMBER: builtins.int
    SERVICE_BUS_NAMESPACE_FIELD_NUMBER: builtins.int
    SERVICE_BUS_SUFFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    hostname: builtins.str
    port: builtins.int
    relay_arm_uri: builtins.str
    relay_name: builtins.str
    send_key_name: builtins.str
    send_key_value: builtins.str
    service_bus_namespace: builtins.str
    service_bus_suffix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        hostname: builtins.str = ...,
        port: builtins.int = ...,
        relay_arm_uri: builtins.str = ...,
        relay_name: builtins.str = ...,
        send_key_name: builtins.str = ...,
        send_key_value: builtins.str = ...,
        service_bus_namespace: builtins.str = ...,
        service_bus_suffix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostname", b"hostname", "kind", b"kind", "name", b"name", "port", b"port", "relay_arm_uri", b"relay_arm_uri", "relay_name", b"relay_name", "resource_info", b"resource_info", "send_key_name", b"send_key_name", "send_key_value", b"send_key_value", "service_bus_namespace", b"service_bus_namespace", "service_bus_suffix", b"service_bus_suffix"]) -> None: ...

global___SitesHybridConnectionNamespacesRelays = SitesHybridConnectionNamespacesRelays

@typing_extensions.final
class SitesHybridconnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BIZTALK_URI_FIELD_NUMBER: builtins.int
    ENTITY_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENTITY_NAME_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    biztalk_uri: builtins.str
    entity_connection_string: builtins.str
    entity_name: builtins.str
    hostname: builtins.str
    port: builtins.int
    resource_connection_string: builtins.str
    resource_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        biztalk_uri: builtins.str = ...,
        entity_connection_string: builtins.str = ...,
        entity_name: builtins.str = ...,
        hostname: builtins.str = ...,
        port: builtins.int = ...,
        resource_connection_string: builtins.str = ...,
        resource_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biztalk_uri", b"biztalk_uri", "entity_connection_string", b"entity_connection_string", "entity_name", b"entity_name", "hostname", b"hostname", "kind", b"kind", "name", b"name", "port", b"port", "resource_connection_string", b"resource_connection_string", "resource_info", b"resource_info", "resource_type", b"resource_type"]) -> None: ...

global___SitesHybridconnection = SitesHybridconnection

@typing_extensions.final
class SitesHostNameBindings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    AZURE_RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    CUSTOM_HOST_NAME_DNS_RECORD_TYPE_FIELD_NUMBER: builtins.int
    DOMAIN_ID_FIELD_NUMBER: builtins.int
    HOST_NAME_TYPE_FIELD_NUMBER: builtins.int
    SITE_NAME_FIELD_NUMBER: builtins.int
    SSL_STATE_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    azure_resource_name: builtins.str
    azure_resource_type: builtins.str
    custom_host_name_dns_record_type: builtins.str
    domain_id: builtins.str
    host_name_type: builtins.str
    site_name: builtins.str
    ssl_state: builtins.str
    thumbprint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        azure_resource_name: builtins.str = ...,
        azure_resource_type: builtins.str = ...,
        custom_host_name_dns_record_type: builtins.str = ...,
        domain_id: builtins.str = ...,
        host_name_type: builtins.str = ...,
        site_name: builtins.str = ...,
        ssl_state: builtins.str = ...,
        thumbprint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_resource_name", b"azure_resource_name", "azure_resource_type", b"azure_resource_type", "custom_host_name_dns_record_type", b"custom_host_name_dns_record_type", "domain_id", b"domain_id", "host_name_type", b"host_name_type", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "site_name", b"site_name", "ssl_state", b"ssl_state", "thumbprint", b"thumbprint"]) -> None: ...

global___SitesHostNameBindings = SitesHostNameBindings

@typing_extensions.final
class SitesFunctionsKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___SitesFunctionsKeys = SitesFunctionsKeys

@typing_extensions.final
class SitesFunctions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class FilesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    CONFIG_HREF_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    FUNCTION_APP_ID_FIELD_NUMBER: builtins.int
    HREF_FIELD_NUMBER: builtins.int
    INVOKE_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    IS_DISABLED_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    SCRIPT_HREF_FIELD_NUMBER: builtins.int
    SCRIPT_ROOT_PATH_HREF_FIELD_NUMBER: builtins.int
    SECRETS_FILE_HREF_FIELD_NUMBER: builtins.int
    TEST_DATA_FIELD_NUMBER: builtins.int
    TEST_DATA_HREF_FIELD_NUMBER: builtins.int
    SITES_FUNCTIONS_KEYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    @property
    def config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    config_href: builtins.str
    @property
    def files(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    function_app_id: builtins.str
    href: builtins.str
    invoke_url_template: builtins.str
    is_disabled: builtins.bool
    language: builtins.str
    script_href: builtins.str
    script_root_path_href: builtins.str
    secrets_file_href: builtins.str
    test_data: builtins.str
    test_data_href: builtins.str
    @property
    def sites_functions_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesFunctionsKeys]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_href: builtins.str = ...,
        files: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        function_app_id: builtins.str = ...,
        href: builtins.str = ...,
        invoke_url_template: builtins.str = ...,
        is_disabled: builtins.bool = ...,
        language: builtins.str = ...,
        script_href: builtins.str = ...,
        script_root_path_href: builtins.str = ...,
        secrets_file_href: builtins.str = ...,
        test_data: builtins.str = ...,
        test_data_href: builtins.str = ...,
        sites_functions_keys: collections.abc.Iterable[global___SitesFunctionsKeys] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "config_href", b"config_href", "files", b"files", "function_app_id", b"function_app_id", "href", b"href", "invoke_url_template", b"invoke_url_template", "is_disabled", b"is_disabled", "kind", b"kind", "language", b"language", "name", b"name", "resource_info", b"resource_info", "script_href", b"script_href", "script_root_path_href", b"script_root_path_href", "secrets_file_href", b"secrets_file_href", "sites_functions_keys", b"sites_functions_keys", "test_data", b"test_data", "test_data_href", b"test_data_href"]) -> None: ...

global___SitesFunctions = SitesFunctions

@typing_extensions.final
class SitesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___SitesExtensions = SitesExtensions

@typing_extensions.final
class SitesDomainOwnershipIdentifiers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___SitesDomainOwnershipIdentifiers = SitesDomainOwnershipIdentifiers

@typing_extensions.final
class SitesDeployments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_EMAIL_FIELD_NUMBER: builtins.int
    DEPLOYER_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    active: builtins.bool
    author: builtins.str
    author_email: builtins.str
    deployer: builtins.str
    details: builtins.str
    end_time: builtins.str
    message: builtins.str
    start_time: builtins.str
    status: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        active: builtins.bool = ...,
        author: builtins.str = ...,
        author_email: builtins.str = ...,
        deployer: builtins.str = ...,
        details: builtins.str = ...,
        end_time: builtins.str = ...,
        message: builtins.str = ...,
        start_time: builtins.str = ...,
        status: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "author", b"author", "author_email", b"author_email", "deployer", b"deployer", "details", b"details", "end_time", b"end_time", "kind", b"kind", "message", b"message", "name", b"name", "resource_info", b"resource_info", "start_time", b"start_time", "status", b"status"]) -> None: ...

global___SitesDeployments = SitesDeployments

@typing_extensions.final
class SitesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FTPS_STATE_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PATH_FIELD_NUMBER: builtins.int
    HTTP20_ENABLED_FIELD_NUMBER: builtins.int
    HTTP_LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    JAVA_CONTAINER_FIELD_NUMBER: builtins.int
    JAVA_CONTAINER_VERSION_FIELD_NUMBER: builtins.int
    JAVA_VERSION_FIELD_NUMBER: builtins.int
    LINUX_FX_VERSION_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_FIELD_NUMBER: builtins.int
    LOGS_DIRECTORY_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    MANAGED_PIPELINE_MODE_FIELD_NUMBER: builtins.int
    MIN_TLS_VERSION_FIELD_NUMBER: builtins.int
    NET_FRAMEWORK_VERSION_FIELD_NUMBER: builtins.int
    NODE_VERSION_FIELD_NUMBER: builtins.int
    PHP_VERSION_FIELD_NUMBER: builtins.int
    PUBLISHING_USERNAME_FIELD_NUMBER: builtins.int
    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    REMOTE_DEBUGGING_ENABLED_FIELD_NUMBER: builtins.int
    REMOTE_DEBUGGING_VERSION_FIELD_NUMBER: builtins.int
    SCM_IP_SECURITY_RESTRICTIONS_USE_MAIN_FIELD_NUMBER: builtins.int
    WINDOWS_FX_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ftps_state: builtins.str
    health_check_path: builtins.str
    http20_enabled: builtins.str
    http_logging_enabled: builtins.str
    java_container: builtins.str
    java_container_version: builtins.str
    java_version: builtins.str
    linux_fx_version: builtins.str
    load_balancing: builtins.str
    logs_directory_size_limit: builtins.str
    managed_pipeline_mode: builtins.str
    min_tls_version: builtins.str
    net_framework_version: builtins.str
    node_version: builtins.str
    php_version: builtins.str
    publishing_username: builtins.str
    python_version: builtins.str
    remote_debugging_enabled: builtins.str
    remote_debugging_version: builtins.str
    scm_ip_security_restrictions_use_main: builtins.str
    windows_fx_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ftps_state: builtins.str = ...,
        health_check_path: builtins.str = ...,
        http20_enabled: builtins.str = ...,
        http_logging_enabled: builtins.str = ...,
        java_container: builtins.str = ...,
        java_container_version: builtins.str = ...,
        java_version: builtins.str = ...,
        linux_fx_version: builtins.str = ...,
        load_balancing: builtins.str = ...,
        logs_directory_size_limit: builtins.str = ...,
        managed_pipeline_mode: builtins.str = ...,
        min_tls_version: builtins.str = ...,
        net_framework_version: builtins.str = ...,
        node_version: builtins.str = ...,
        php_version: builtins.str = ...,
        publishing_username: builtins.str = ...,
        python_version: builtins.str = ...,
        remote_debugging_enabled: builtins.str = ...,
        remote_debugging_version: builtins.str = ...,
        scm_ip_security_restrictions_use_main: builtins.str = ...,
        windows_fx_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ftps_state", b"ftps_state", "health_check_path", b"health_check_path", "http20_enabled", b"http20_enabled", "http_logging_enabled", b"http_logging_enabled", "java_container", b"java_container", "java_container_version", b"java_container_version", "java_version", b"java_version", "linux_fx_version", b"linux_fx_version", "load_balancing", b"load_balancing", "logs_directory_size_limit", b"logs_directory_size_limit", "managed_pipeline_mode", b"managed_pipeline_mode", "min_tls_version", b"min_tls_version", "net_framework_version", b"net_framework_version", "node_version", b"node_version", "php_version", b"php_version", "publishing_username", b"publishing_username", "python_version", b"python_version", "remote_debugging_enabled", b"remote_debugging_enabled", "remote_debugging_version", b"remote_debugging_version", "resource_info", b"resource_info", "scm_ip_security_restrictions_use_main", b"scm_ip_security_restrictions_use_main", "windows_fx_version", b"windows_fx_version"]) -> None: ...

global___SitesConfig = SitesConfig

@typing_extensions.final
class SitesBasicPublishingCredentialsPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___SitesBasicPublishingCredentialsPolicies = SitesBasicPublishingCredentialsPolicies

@typing_extensions.final
class Sites(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLIENT_AFFINITY_ENABLED_FIELD_NUMBER: builtins.int
    CLIENT_CERT_ENABLED_FIELD_NUMBER: builtins.int
    CLIENT_CERT_EXCLUSION_PATHS_FIELD_NUMBER: builtins.int
    CLIENT_CERT_MODE_FIELD_NUMBER: builtins.int
    CLONING_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_SIZE_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_VERIFICATION_ID_FIELD_NUMBER: builtins.int
    DAILY_MEMORY_TIME_QUOTA_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENT_PROFILE_FIELD_NUMBER: builtins.int
    HOST_NAMES_DISABLED_FIELD_NUMBER: builtins.int
    HOST_NAME_SSL_STATES_FIELD_NUMBER: builtins.int
    HTTPS_ONLY_FIELD_NUMBER: builtins.int
    HYPER_V_FIELD_NUMBER: builtins.int
    IS_XENON_FIELD_NUMBER: builtins.int
    KEY_VAULT_REFERENCE_IDENTITY_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    REDUNDANCY_MODE_FIELD_NUMBER: builtins.int
    RESERVED_FIELD_NUMBER: builtins.int
    SCM_SITE_ALSO_STOPPED_FIELD_NUMBER: builtins.int
    SERVER_FARM_ID_FIELD_NUMBER: builtins.int
    SITE_CONFIG_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_REQUIRED_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_SUBNET_ID_FIELD_NUMBER: builtins.int
    VNET_CONTENT_SHARE_ENABLED_FIELD_NUMBER: builtins.int
    VNET_IMAGE_PULL_ENABLED_FIELD_NUMBER: builtins.int
    VNET_ROUTE_ALL_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SITES_BASIC_PUBLISHING_CREDENTIALS_POLICIES_FIELD_NUMBER: builtins.int
    SITES_DOMAIN_OWNERSHIP_IDENTIFIERS_FIELD_NUMBER: builtins.int
    SITES_EXTENSIONS_FIELD_NUMBER: builtins.int
    SITES_FUNCTIONS_FIELD_NUMBER: builtins.int
    SITES_HYBRIDCONNECTION_FIELD_NUMBER: builtins.int
    SITES_MIGRATE_FIELD_NUMBER: builtins.int
    SITES_NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    SITES_PREMIERADDONS_FIELD_NUMBER: builtins.int
    SITES_PRIVATE_ACCESS_FIELD_NUMBER: builtins.int
    SITES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    SITES_PUBLIC_CERTIFICATES_FIELD_NUMBER: builtins.int
    SITES_SITEEXTENSIONS_FIELD_NUMBER: builtins.int
    SITES_SLOTS_FIELD_NUMBER: builtins.int
    SITES_SOURCECONTROLS_FIELD_NUMBER: builtins.int
    SITES_VIRTUAL_NETWORK_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    client_affinity_enabled: builtins.bool
    client_cert_enabled: builtins.bool
    client_cert_exclusion_paths: builtins.str
    client_cert_mode: builtins.str
    @property
    def cloning_info(self) -> global___CloningInfo: ...
    container_size: builtins.int
    custom_domain_verification_id: builtins.str
    daily_memory_time_quota: builtins.int
    enabled: builtins.bool
    @property
    def hosting_environment_profile(self) -> global___HostingEnvironmentProfile: ...
    host_names_disabled: builtins.bool
    @property
    def host_name_ssl_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostNameSslState]: ...
    https_only: builtins.bool
    hyper_v: builtins.bool
    is_xenon: builtins.bool
    key_vault_reference_identity: builtins.str
    public_network_access: builtins.str
    redundancy_mode: builtins.str
    reserved: builtins.bool
    scm_site_also_stopped: builtins.bool
    server_farm_id: builtins.str
    @property
    def site_config(self) -> global___SiteConfig: ...
    storage_account_required: builtins.bool
    virtual_network_subnet_id: builtins.str
    vnet_content_share_enabled: builtins.bool
    vnet_image_pull_enabled: builtins.bool
    vnet_route_all_enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sites_basic_publishing_credentials_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesBasicPublishingCredentialsPolicies]: ...
    @property
    def sites_domain_ownership_identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesDomainOwnershipIdentifiers]: ...
    @property
    def sites_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesExtensions]: ...
    @property
    def sites_functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesFunctions]: ...
    @property
    def sites_hybridconnection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesHybridconnection]: ...
    @property
    def sites_migrate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesMigrate]: ...
    @property
    def sites_network_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesNetworkConfig]: ...
    @property
    def sites_premieraddons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesPremieraddons]: ...
    @property
    def sites_private_access(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesPrivateAccess]: ...
    @property
    def sites_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesPrivateEndpointConnections]: ...
    @property
    def sites_public_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesPublicCertificates]: ...
    @property
    def sites_siteextensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSiteextensions]: ...
    @property
    def sites_slots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSlots]: ...
    @property
    def sites_sourcecontrols(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesSourcecontrols]: ...
    @property
    def sites_virtual_network_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SitesVirtualNetworkConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        client_affinity_enabled: builtins.bool = ...,
        client_cert_enabled: builtins.bool = ...,
        client_cert_exclusion_paths: builtins.str = ...,
        client_cert_mode: builtins.str = ...,
        cloning_info: global___CloningInfo | None = ...,
        container_size: builtins.int = ...,
        custom_domain_verification_id: builtins.str = ...,
        daily_memory_time_quota: builtins.int = ...,
        enabled: builtins.bool = ...,
        hosting_environment_profile: global___HostingEnvironmentProfile | None = ...,
        host_names_disabled: builtins.bool = ...,
        host_name_ssl_states: collections.abc.Iterable[global___HostNameSslState] | None = ...,
        https_only: builtins.bool = ...,
        hyper_v: builtins.bool = ...,
        is_xenon: builtins.bool = ...,
        key_vault_reference_identity: builtins.str = ...,
        public_network_access: builtins.str = ...,
        redundancy_mode: builtins.str = ...,
        reserved: builtins.bool = ...,
        scm_site_also_stopped: builtins.bool = ...,
        server_farm_id: builtins.str = ...,
        site_config: global___SiteConfig | None = ...,
        storage_account_required: builtins.bool = ...,
        virtual_network_subnet_id: builtins.str = ...,
        vnet_content_share_enabled: builtins.bool = ...,
        vnet_image_pull_enabled: builtins.bool = ...,
        vnet_route_all_enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sites_basic_publishing_credentials_policies: collections.abc.Iterable[global___SitesBasicPublishingCredentialsPolicies] | None = ...,
        sites_domain_ownership_identifiers: collections.abc.Iterable[global___SitesDomainOwnershipIdentifiers] | None = ...,
        sites_extensions: collections.abc.Iterable[global___SitesExtensions] | None = ...,
        sites_functions: collections.abc.Iterable[global___SitesFunctions] | None = ...,
        sites_hybridconnection: collections.abc.Iterable[global___SitesHybridconnection] | None = ...,
        sites_migrate: collections.abc.Iterable[global___SitesMigrate] | None = ...,
        sites_network_config: collections.abc.Iterable[global___SitesNetworkConfig] | None = ...,
        sites_premieraddons: collections.abc.Iterable[global___SitesPremieraddons] | None = ...,
        sites_private_access: collections.abc.Iterable[global___SitesPrivateAccess] | None = ...,
        sites_private_endpoint_connections: collections.abc.Iterable[global___SitesPrivateEndpointConnections] | None = ...,
        sites_public_certificates: collections.abc.Iterable[global___SitesPublicCertificates] | None = ...,
        sites_siteextensions: collections.abc.Iterable[global___SitesSiteextensions] | None = ...,
        sites_slots: collections.abc.Iterable[global___SitesSlots] | None = ...,
        sites_sourcecontrols: collections.abc.Iterable[global___SitesSourcecontrols] | None = ...,
        sites_virtual_network_connections: collections.abc.Iterable[global___SitesVirtualNetworkConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloning_info", b"cloning_info", "extended_location", b"extended_location", "hosting_environment_profile", b"hosting_environment_profile", "identity", b"identity", "resource_info", b"resource_info", "site_config", b"site_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_affinity_enabled", b"client_affinity_enabled", "client_cert_enabled", b"client_cert_enabled", "client_cert_exclusion_paths", b"client_cert_exclusion_paths", "client_cert_mode", b"client_cert_mode", "cloning_info", b"cloning_info", "container_size", b"container_size", "custom_domain_verification_id", b"custom_domain_verification_id", "daily_memory_time_quota", b"daily_memory_time_quota", "enabled", b"enabled", "extended_location", b"extended_location", "host_name_ssl_states", b"host_name_ssl_states", "host_names_disabled", b"host_names_disabled", "hosting_environment_profile", b"hosting_environment_profile", "https_only", b"https_only", "hyper_v", b"hyper_v", "identity", b"identity", "is_xenon", b"is_xenon", "key_vault_reference_identity", b"key_vault_reference_identity", "kind", b"kind", "location", b"location", "name", b"name", "public_network_access", b"public_network_access", "redundancy_mode", b"redundancy_mode", "reserved", b"reserved", "resource_info", b"resource_info", "scm_site_also_stopped", b"scm_site_also_stopped", "server_farm_id", b"server_farm_id", "site_config", b"site_config", "sites_basic_publishing_credentials_policies", b"sites_basic_publishing_credentials_policies", "sites_domain_ownership_identifiers", b"sites_domain_ownership_identifiers", "sites_extensions", b"sites_extensions", "sites_functions", b"sites_functions", "sites_hybridconnection", b"sites_hybridconnection", "sites_migrate", b"sites_migrate", "sites_network_config", b"sites_network_config", "sites_premieraddons", b"sites_premieraddons", "sites_private_access", b"sites_private_access", "sites_private_endpoint_connections", b"sites_private_endpoint_connections", "sites_public_certificates", b"sites_public_certificates", "sites_siteextensions", b"sites_siteextensions", "sites_slots", b"sites_slots", "sites_sourcecontrols", b"sites_sourcecontrols", "sites_virtual_network_connections", b"sites_virtual_network_connections", "storage_account_required", b"storage_account_required", "tags", b"tags", "virtual_network_subnet_id", b"virtual_network_subnet_id", "vnet_content_share_enabled", b"vnet_content_share_enabled", "vnet_image_pull_enabled", b"vnet_image_pull_enabled", "vnet_route_all_enabled", b"vnet_route_all_enabled"]) -> None: ...

global___Sites = Sites

@typing_extensions.final
class SiteConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AzureStorageAccountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACR_USE_MANAGED_IDENTITY_CREDS_FIELD_NUMBER: builtins.int
    ACR_USER_MANAGED_IDENTITY_ID_FIELD_NUMBER: builtins.int
    ALWAYS_ON_FIELD_NUMBER: builtins.int
    API_DEFINITION_FIELD_NUMBER: builtins.int
    API_MANAGEMENT_CONFIG_FIELD_NUMBER: builtins.int
    APP_COMMAND_LINE_FIELD_NUMBER: builtins.int
    APP_SETTINGS_FIELD_NUMBER: builtins.int
    AUTO_HEAL_ENABLED_FIELD_NUMBER: builtins.int
    AUTO_HEAL_RULES_FIELD_NUMBER: builtins.int
    AUTO_SWAP_SLOT_NAME_FIELD_NUMBER: builtins.int
    AZURE_STORAGE_ACCOUNTS_FIELD_NUMBER: builtins.int
    CONNECTION_STRINGS_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    DEFAULT_DOCUMENTS_FIELD_NUMBER: builtins.int
    DETAILED_ERROR_LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    DOCUMENT_ROOT_FIELD_NUMBER: builtins.int
    EXPERIMENTS_FIELD_NUMBER: builtins.int
    FTPS_STATE_FIELD_NUMBER: builtins.int
    FUNCTION_APP_SCALE_LIMIT_FIELD_NUMBER: builtins.int
    FUNCTIONS_RUNTIME_SCALE_MONITORING_ENABLED_FIELD_NUMBER: builtins.int
    HANDLER_MAPPINGS_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PATH_FIELD_NUMBER: builtins.int
    HTTP20_ENABLED_FIELD_NUMBER: builtins.int
    HTTP_LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    IP_SECURITY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    JAVA_CONTAINER_FIELD_NUMBER: builtins.int
    JAVA_CONTAINER_VERSION_FIELD_NUMBER: builtins.int
    JAVA_VERSION_FIELD_NUMBER: builtins.int
    KEY_VAULT_REFERENCE_IDENTITY_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    LINUX_FX_VERSION_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_FIELD_NUMBER: builtins.int
    LOCAL_MY_SQL_ENABLED_FIELD_NUMBER: builtins.int
    LOGS_DIRECTORY_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    MANAGED_PIPELINE_MODE_FIELD_NUMBER: builtins.int
    MANAGED_SERVICE_IDENTITY_ID_FIELD_NUMBER: builtins.int
    MINIMUM_ELASTIC_INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    MIN_TLS_VERSION_FIELD_NUMBER: builtins.int
    NET_FRAMEWORK_VERSION_FIELD_NUMBER: builtins.int
    NODE_VERSION_FIELD_NUMBER: builtins.int
    NUMBER_OF_WORKERS_FIELD_NUMBER: builtins.int
    PHP_VERSION_FIELD_NUMBER: builtins.int
    POWER_SHELL_VERSION_FIELD_NUMBER: builtins.int
    PRE_WARMED_INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    PUBLISHING_USERNAME_FIELD_NUMBER: builtins.int
    PUSH_FIELD_NUMBER: builtins.int
    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    REMOTE_DEBUGGING_ENABLED_FIELD_NUMBER: builtins.int
    REMOTE_DEBUGGING_VERSION_FIELD_NUMBER: builtins.int
    REQUEST_TRACING_ENABLED_FIELD_NUMBER: builtins.int
    REQUEST_TRACING_EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    SCM_IP_SECURITY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    SCM_IP_SECURITY_RESTRICTIONS_USE_MAIN_FIELD_NUMBER: builtins.int
    SCM_MIN_TLS_VERSION_FIELD_NUMBER: builtins.int
    SCM_TYPE_FIELD_NUMBER: builtins.int
    TRACING_OPTIONS_FIELD_NUMBER: builtins.int
    USE32_BIT_WORKER_PROCESS_FIELD_NUMBER: builtins.int
    VIRTUAL_APPLICATIONS_FIELD_NUMBER: builtins.int
    VNET_NAME_FIELD_NUMBER: builtins.int
    VNET_PRIVATE_PORTS_COUNT_FIELD_NUMBER: builtins.int
    VNET_ROUTE_ALL_ENABLED_FIELD_NUMBER: builtins.int
    WEBSITE_TIME_ZONE_FIELD_NUMBER: builtins.int
    WEB_SOCKETS_ENABLED_FIELD_NUMBER: builtins.int
    WINDOWS_FX_VERSION_FIELD_NUMBER: builtins.int
    X_MANAGED_SERVICE_IDENTITY_ID_FIELD_NUMBER: builtins.int
    acr_use_managed_identity_creds: builtins.bool
    acr_user_managed_identity_id: builtins.str
    always_on: builtins.bool
    @property
    def api_definition(self) -> global___ApiDefinitionInfo: ...
    @property
    def api_management_config(self) -> global___ApiManagementConfig: ...
    app_command_line: builtins.str
    @property
    def app_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameValuePair]: ...
    auto_heal_enabled: builtins.bool
    @property
    def auto_heal_rules(self) -> global___AutoHealRules: ...
    auto_swap_slot_name: builtins.str
    @property
    def azure_storage_accounts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def connection_strings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnStringInfo]: ...
    @property
    def cors(self) -> global___CorsSettings: ...
    @property
    def default_documents(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    detailed_error_logging_enabled: builtins.bool
    document_root: builtins.str
    @property
    def experiments(self) -> global___Experiments: ...
    ftps_state: builtins.str
    function_app_scale_limit: builtins.int
    functions_runtime_scale_monitoring_enabled: builtins.bool
    @property
    def handler_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HandlerMapping]: ...
    health_check_path: builtins.str
    http20_enabled: builtins.bool
    http_logging_enabled: builtins.bool
    @property
    def ip_security_restrictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IpSecurityRestriction]: ...
    java_container: builtins.str
    java_container_version: builtins.str
    java_version: builtins.str
    key_vault_reference_identity: builtins.str
    @property
    def limits(self) -> global___SiteLimits: ...
    linux_fx_version: builtins.str
    load_balancing: builtins.str
    local_my_sql_enabled: builtins.bool
    logs_directory_size_limit: builtins.int
    managed_pipeline_mode: builtins.str
    managed_service_identity_id: builtins.int
    minimum_elastic_instance_count: builtins.int
    min_tls_version: builtins.str
    net_framework_version: builtins.str
    node_version: builtins.str
    number_of_workers: builtins.int
    php_version: builtins.str
    power_shell_version: builtins.str
    pre_warmed_instance_count: builtins.int
    public_network_access: builtins.str
    publishing_username: builtins.str
    @property
    def push(self) -> global___PushSettings: ...
    python_version: builtins.str
    remote_debugging_enabled: builtins.bool
    remote_debugging_version: builtins.str
    request_tracing_enabled: builtins.bool
    request_tracing_expiration_time: builtins.str
    @property
    def scm_ip_security_restrictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IpSecurityRestriction]: ...
    scm_ip_security_restrictions_use_main: builtins.bool
    scm_min_tls_version: builtins.str
    scm_type: builtins.str
    tracing_options: builtins.str
    use32_bit_worker_process: builtins.bool
    @property
    def virtual_applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualApplication]: ...
    vnet_name: builtins.str
    vnet_private_ports_count: builtins.int
    vnet_route_all_enabled: builtins.bool
    website_time_zone: builtins.str
    web_sockets_enabled: builtins.bool
    windows_fx_version: builtins.str
    x_managed_service_identity_id: builtins.int
    def __init__(
        self,
        *,
        acr_use_managed_identity_creds: builtins.bool = ...,
        acr_user_managed_identity_id: builtins.str = ...,
        always_on: builtins.bool = ...,
        api_definition: global___ApiDefinitionInfo | None = ...,
        api_management_config: global___ApiManagementConfig | None = ...,
        app_command_line: builtins.str = ...,
        app_settings: collections.abc.Iterable[global___NameValuePair] | None = ...,
        auto_heal_enabled: builtins.bool = ...,
        auto_heal_rules: global___AutoHealRules | None = ...,
        auto_swap_slot_name: builtins.str = ...,
        azure_storage_accounts: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connection_strings: collections.abc.Iterable[global___ConnStringInfo] | None = ...,
        cors: global___CorsSettings | None = ...,
        default_documents: collections.abc.Iterable[builtins.str] | None = ...,
        detailed_error_logging_enabled: builtins.bool = ...,
        document_root: builtins.str = ...,
        experiments: global___Experiments | None = ...,
        ftps_state: builtins.str = ...,
        function_app_scale_limit: builtins.int = ...,
        functions_runtime_scale_monitoring_enabled: builtins.bool = ...,
        handler_mappings: collections.abc.Iterable[global___HandlerMapping] | None = ...,
        health_check_path: builtins.str = ...,
        http20_enabled: builtins.bool = ...,
        http_logging_enabled: builtins.bool = ...,
        ip_security_restrictions: collections.abc.Iterable[global___IpSecurityRestriction] | None = ...,
        java_container: builtins.str = ...,
        java_container_version: builtins.str = ...,
        java_version: builtins.str = ...,
        key_vault_reference_identity: builtins.str = ...,
        limits: global___SiteLimits | None = ...,
        linux_fx_version: builtins.str = ...,
        load_balancing: builtins.str = ...,
        local_my_sql_enabled: builtins.bool = ...,
        logs_directory_size_limit: builtins.int = ...,
        managed_pipeline_mode: builtins.str = ...,
        managed_service_identity_id: builtins.int = ...,
        minimum_elastic_instance_count: builtins.int = ...,
        min_tls_version: builtins.str = ...,
        net_framework_version: builtins.str = ...,
        node_version: builtins.str = ...,
        number_of_workers: builtins.int = ...,
        php_version: builtins.str = ...,
        power_shell_version: builtins.str = ...,
        pre_warmed_instance_count: builtins.int = ...,
        public_network_access: builtins.str = ...,
        publishing_username: builtins.str = ...,
        push: global___PushSettings | None = ...,
        python_version: builtins.str = ...,
        remote_debugging_enabled: builtins.bool = ...,
        remote_debugging_version: builtins.str = ...,
        request_tracing_enabled: builtins.bool = ...,
        request_tracing_expiration_time: builtins.str = ...,
        scm_ip_security_restrictions: collections.abc.Iterable[global___IpSecurityRestriction] | None = ...,
        scm_ip_security_restrictions_use_main: builtins.bool = ...,
        scm_min_tls_version: builtins.str = ...,
        scm_type: builtins.str = ...,
        tracing_options: builtins.str = ...,
        use32_bit_worker_process: builtins.bool = ...,
        virtual_applications: collections.abc.Iterable[global___VirtualApplication] | None = ...,
        vnet_name: builtins.str = ...,
        vnet_private_ports_count: builtins.int = ...,
        vnet_route_all_enabled: builtins.bool = ...,
        website_time_zone: builtins.str = ...,
        web_sockets_enabled: builtins.bool = ...,
        windows_fx_version: builtins.str = ...,
        x_managed_service_identity_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api_definition", b"api_definition", "api_management_config", b"api_management_config", "auto_heal_rules", b"auto_heal_rules", "cors", b"cors", "experiments", b"experiments", "limits", b"limits", "push", b"push"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["acr_use_managed_identity_creds", b"acr_use_managed_identity_creds", "acr_user_managed_identity_id", b"acr_user_managed_identity_id", "always_on", b"always_on", "api_definition", b"api_definition", "api_management_config", b"api_management_config", "app_command_line", b"app_command_line", "app_settings", b"app_settings", "auto_heal_enabled", b"auto_heal_enabled", "auto_heal_rules", b"auto_heal_rules", "auto_swap_slot_name", b"auto_swap_slot_name", "azure_storage_accounts", b"azure_storage_accounts", "connection_strings", b"connection_strings", "cors", b"cors", "default_documents", b"default_documents", "detailed_error_logging_enabled", b"detailed_error_logging_enabled", "document_root", b"document_root", "experiments", b"experiments", "ftps_state", b"ftps_state", "function_app_scale_limit", b"function_app_scale_limit", "functions_runtime_scale_monitoring_enabled", b"functions_runtime_scale_monitoring_enabled", "handler_mappings", b"handler_mappings", "health_check_path", b"health_check_path", "http20_enabled", b"http20_enabled", "http_logging_enabled", b"http_logging_enabled", "ip_security_restrictions", b"ip_security_restrictions", "java_container", b"java_container", "java_container_version", b"java_container_version", "java_version", b"java_version", "key_vault_reference_identity", b"key_vault_reference_identity", "limits", b"limits", "linux_fx_version", b"linux_fx_version", "load_balancing", b"load_balancing", "local_my_sql_enabled", b"local_my_sql_enabled", "logs_directory_size_limit", b"logs_directory_size_limit", "managed_pipeline_mode", b"managed_pipeline_mode", "managed_service_identity_id", b"managed_service_identity_id", "min_tls_version", b"min_tls_version", "minimum_elastic_instance_count", b"minimum_elastic_instance_count", "net_framework_version", b"net_framework_version", "node_version", b"node_version", "number_of_workers", b"number_of_workers", "php_version", b"php_version", "power_shell_version", b"power_shell_version", "pre_warmed_instance_count", b"pre_warmed_instance_count", "public_network_access", b"public_network_access", "publishing_username", b"publishing_username", "push", b"push", "python_version", b"python_version", "remote_debugging_enabled", b"remote_debugging_enabled", "remote_debugging_version", b"remote_debugging_version", "request_tracing_enabled", b"request_tracing_enabled", "request_tracing_expiration_time", b"request_tracing_expiration_time", "scm_ip_security_restrictions", b"scm_ip_security_restrictions", "scm_ip_security_restrictions_use_main", b"scm_ip_security_restrictions_use_main", "scm_min_tls_version", b"scm_min_tls_version", "scm_type", b"scm_type", "tracing_options", b"tracing_options", "use32_bit_worker_process", b"use32_bit_worker_process", "virtual_applications", b"virtual_applications", "vnet_name", b"vnet_name", "vnet_private_ports_count", b"vnet_private_ports_count", "vnet_route_all_enabled", b"vnet_route_all_enabled", "web_sockets_enabled", b"web_sockets_enabled", "website_time_zone", b"website_time_zone", "windows_fx_version", b"windows_fx_version", "x_managed_service_identity_id", b"x_managed_service_identity_id"]) -> None: ...

global___SiteConfig = SiteConfig

@typing_extensions.final
class VirtualApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_PATH_FIELD_NUMBER: builtins.int
    PRELOAD_ENABLED_FIELD_NUMBER: builtins.int
    VIRTUAL_DIRECTORIES_FIELD_NUMBER: builtins.int
    VIRTUAL_PATH_FIELD_NUMBER: builtins.int
    physical_path: builtins.str
    preload_enabled: builtins.bool
    @property
    def virtual_directories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualDirectory]: ...
    virtual_path: builtins.str
    def __init__(
        self,
        *,
        physical_path: builtins.str = ...,
        preload_enabled: builtins.bool = ...,
        virtual_directories: collections.abc.Iterable[global___VirtualDirectory] | None = ...,
        virtual_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["physical_path", b"physical_path", "preload_enabled", b"preload_enabled", "virtual_directories", b"virtual_directories", "virtual_path", b"virtual_path"]) -> None: ...

global___VirtualApplication = VirtualApplication

@typing_extensions.final
class VirtualDirectory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHYSICAL_PATH_FIELD_NUMBER: builtins.int
    VIRTUAL_PATH_FIELD_NUMBER: builtins.int
    physical_path: builtins.str
    virtual_path: builtins.str
    def __init__(
        self,
        *,
        physical_path: builtins.str = ...,
        virtual_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["physical_path", b"physical_path", "virtual_path", b"virtual_path"]) -> None: ...

global___VirtualDirectory = VirtualDirectory

@typing_extensions.final
class PushSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    DYNAMIC_TAGS_JSON_FIELD_NUMBER: builtins.int
    IS_PUSH_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_REQUIRING_AUTH_FIELD_NUMBER: builtins.int
    TAG_WHITELIST_JSON_FIELD_NUMBER: builtins.int
    kind: builtins.str
    dynamic_tags_json: builtins.str
    is_push_enabled: builtins.bool
    tags_requiring_auth: builtins.str
    tag_whitelist_json: builtins.str
    def __init__(
        self,
        *,
        kind: builtins.str = ...,
        dynamic_tags_json: builtins.str = ...,
        is_push_enabled: builtins.bool = ...,
        tags_requiring_auth: builtins.str = ...,
        tag_whitelist_json: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_tags_json", b"dynamic_tags_json", "is_push_enabled", b"is_push_enabled", "kind", b"kind", "tag_whitelist_json", b"tag_whitelist_json", "tags_requiring_auth", b"tags_requiring_auth"]) -> None: ...

global___PushSettings = PushSettings

@typing_extensions.final
class SiteLimits(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_DISK_SIZE_IN_MB_FIELD_NUMBER: builtins.int
    MAX_MEMORY_IN_MB_FIELD_NUMBER: builtins.int
    MAX_PERCENTAGE_CPU_FIELD_NUMBER: builtins.int
    max_disk_size_in_mb: builtins.int
    max_memory_in_mb: builtins.int
    max_percentage_cpu: builtins.float
    def __init__(
        self,
        *,
        max_disk_size_in_mb: builtins.int = ...,
        max_memory_in_mb: builtins.int = ...,
        max_percentage_cpu: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_disk_size_in_mb", b"max_disk_size_in_mb", "max_memory_in_mb", b"max_memory_in_mb", "max_percentage_cpu", b"max_percentage_cpu"]) -> None: ...

global___SiteLimits = SiteLimits

@typing_extensions.final
class IpSecurityRestriction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    SUBNET_MASK_FIELD_NUMBER: builtins.int
    SUBNET_TRAFFIC_TAG_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    VNET_SUBNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    VNET_TRAFFIC_TAG_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ip_address: builtins.str
    name: builtins.str
    priority: builtins.int
    subnet_mask: builtins.str
    subnet_traffic_tag: builtins.int
    tag: builtins.str
    vnet_subnet_resource_id: builtins.str
    vnet_traffic_tag: builtins.int
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ip_address: builtins.str = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        subnet_mask: builtins.str = ...,
        subnet_traffic_tag: builtins.int = ...,
        tag: builtins.str = ...,
        vnet_subnet_resource_id: builtins.str = ...,
        vnet_traffic_tag: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "headers", b"headers", "ip_address", b"ip_address", "name", b"name", "priority", b"priority", "subnet_mask", b"subnet_mask", "subnet_traffic_tag", b"subnet_traffic_tag", "tag", b"tag", "vnet_subnet_resource_id", b"vnet_subnet_resource_id", "vnet_traffic_tag", b"vnet_traffic_tag"]) -> None: ...

global___IpSecurityRestriction = IpSecurityRestriction

@typing_extensions.final
class HandlerMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGUMENTS_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    SCRIPT_PROCESSOR_FIELD_NUMBER: builtins.int
    arguments: builtins.str
    extension: builtins.str
    script_processor: builtins.str
    def __init__(
        self,
        *,
        arguments: builtins.str = ...,
        extension: builtins.str = ...,
        script_processor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arguments", b"arguments", "extension", b"extension", "script_processor", b"script_processor"]) -> None: ...

global___HandlerMapping = HandlerMapping

@typing_extensions.final
class Experiments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAMP_UP_RULES_FIELD_NUMBER: builtins.int
    @property
    def ramp_up_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RampUpRule]: ...
    def __init__(
        self,
        *,
        ramp_up_rules: collections.abc.Iterable[global___RampUpRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ramp_up_rules", b"ramp_up_rules"]) -> None: ...

global___Experiments = Experiments

@typing_extensions.final
class RampUpRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_HOST_NAME_FIELD_NUMBER: builtins.int
    CHANGE_DECISION_CALLBACK_URL_FIELD_NUMBER: builtins.int
    CHANGE_INTERVAL_IN_MINUTES_FIELD_NUMBER: builtins.int
    CHANGE_STEP_FIELD_NUMBER: builtins.int
    MAX_REROUTE_PERCENTAGE_FIELD_NUMBER: builtins.int
    MIN_REROUTE_PERCENTAGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REROUTE_PERCENTAGE_FIELD_NUMBER: builtins.int
    action_host_name: builtins.str
    change_decision_callback_url: builtins.str
    change_interval_in_minutes: builtins.int
    change_step: builtins.float
    max_reroute_percentage: builtins.float
    min_reroute_percentage: builtins.float
    name: builtins.str
    reroute_percentage: builtins.float
    def __init__(
        self,
        *,
        action_host_name: builtins.str = ...,
        change_decision_callback_url: builtins.str = ...,
        change_interval_in_minutes: builtins.int = ...,
        change_step: builtins.float = ...,
        max_reroute_percentage: builtins.float = ...,
        min_reroute_percentage: builtins.float = ...,
        name: builtins.str = ...,
        reroute_percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_host_name", b"action_host_name", "change_decision_callback_url", b"change_decision_callback_url", "change_interval_in_minutes", b"change_interval_in_minutes", "change_step", b"change_step", "max_reroute_percentage", b"max_reroute_percentage", "min_reroute_percentage", b"min_reroute_percentage", "name", b"name", "reroute_percentage", b"reroute_percentage"]) -> None: ...

global___RampUpRule = RampUpRule

@typing_extensions.final
class CorsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_ORIGINS_FIELD_NUMBER: builtins.int
    SUPPORT_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def allowed_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    support_credentials: builtins.bool
    def __init__(
        self,
        *,
        allowed_origins: collections.abc.Iterable[builtins.str] | None = ...,
        support_credentials: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_origins", b"allowed_origins", "support_credentials", b"support_credentials"]) -> None: ...

global___CorsSettings = CorsSettings

@typing_extensions.final
class ConnStringInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    connection_string: builtins.str
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        connection_string: builtins.str = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_string", b"connection_string", "name", b"name", "type", b"type"]) -> None: ...

global___ConnStringInfo = ConnStringInfo

@typing_extensions.final
class AutoHealRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_FIELD_NUMBER: builtins.int
    TRIGGERS_FIELD_NUMBER: builtins.int
    @property
    def actions(self) -> global___AutoHealActions: ...
    @property
    def triggers(self) -> global___AutoHealTriggers: ...
    def __init__(
        self,
        *,
        actions: global___AutoHealActions | None = ...,
        triggers: global___AutoHealTriggers | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["actions", b"actions", "triggers", b"triggers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "triggers", b"triggers"]) -> None: ...

global___AutoHealRules = AutoHealRules

@typing_extensions.final
class AutoHealTriggers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_BYTES_IN_KB_FIELD_NUMBER: builtins.int
    REQUESTS_FIELD_NUMBER: builtins.int
    SLOW_REQUESTS_FIELD_NUMBER: builtins.int
    SLOW_REQUESTS_WITH_PATH_FIELD_NUMBER: builtins.int
    STATUS_CODES_FIELD_NUMBER: builtins.int
    STATUS_CODES_RANGE_FIELD_NUMBER: builtins.int
    private_bytes_in_kb: builtins.int
    @property
    def requests(self) -> global___RequestsBasedTrigger: ...
    @property
    def slow_requests(self) -> global___SlowRequestsBasedTrigger: ...
    @property
    def slow_requests_with_path(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SlowRequestsBasedTrigger]: ...
    @property
    def status_codes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatusCodesBasedTrigger]: ...
    @property
    def status_codes_range(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatusCodesRangeBasedTrigger]: ...
    def __init__(
        self,
        *,
        private_bytes_in_kb: builtins.int = ...,
        requests: global___RequestsBasedTrigger | None = ...,
        slow_requests: global___SlowRequestsBasedTrigger | None = ...,
        slow_requests_with_path: collections.abc.Iterable[global___SlowRequestsBasedTrigger] | None = ...,
        status_codes: collections.abc.Iterable[global___StatusCodesBasedTrigger] | None = ...,
        status_codes_range: collections.abc.Iterable[global___StatusCodesRangeBasedTrigger] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["requests", b"requests", "slow_requests", b"slow_requests"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_bytes_in_kb", b"private_bytes_in_kb", "requests", b"requests", "slow_requests", b"slow_requests", "slow_requests_with_path", b"slow_requests_with_path", "status_codes", b"status_codes", "status_codes_range", b"status_codes_range"]) -> None: ...

global___AutoHealTriggers = AutoHealTriggers

@typing_extensions.final
class StatusCodesRangeBasedTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    STATUS_CODES_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    count: builtins.int
    path: builtins.str
    status_codes: builtins.str
    time_interval: builtins.str
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        path: builtins.str = ...,
        status_codes: builtins.str = ...,
        time_interval: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "path", b"path", "status_codes", b"status_codes", "time_interval", b"time_interval"]) -> None: ...

global___StatusCodesRangeBasedTrigger = StatusCodesRangeBasedTrigger

@typing_extensions.final
class StatusCodesBasedTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SUB_STATUS_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    WIN32_STATUS_FIELD_NUMBER: builtins.int
    count: builtins.int
    path: builtins.str
    status: builtins.int
    sub_status: builtins.int
    time_interval: builtins.str
    win32_status: builtins.int
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        path: builtins.str = ...,
        status: builtins.int = ...,
        sub_status: builtins.int = ...,
        time_interval: builtins.str = ...,
        win32_status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "path", b"path", "status", b"status", "sub_status", b"sub_status", "time_interval", b"time_interval", "win32_status", b"win32_status"]) -> None: ...

global___StatusCodesBasedTrigger = StatusCodesBasedTrigger

@typing_extensions.final
class SlowRequestsBasedTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    TIME_TAKEN_FIELD_NUMBER: builtins.int
    count: builtins.int
    path: builtins.str
    time_interval: builtins.str
    time_taken: builtins.str
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        path: builtins.str = ...,
        time_interval: builtins.str = ...,
        time_taken: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "path", b"path", "time_interval", b"time_interval", "time_taken", b"time_taken"]) -> None: ...

global___SlowRequestsBasedTrigger = SlowRequestsBasedTrigger

@typing_extensions.final
class RequestsBasedTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    count: builtins.int
    time_interval: builtins.str
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        time_interval: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "time_interval", b"time_interval"]) -> None: ...

global___RequestsBasedTrigger = RequestsBasedTrigger

@typing_extensions.final
class AutoHealActions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_TYPE_FIELD_NUMBER: builtins.int
    CUSTOM_ACTION_FIELD_NUMBER: builtins.int
    MIN_PROCESS_EXECUTION_TIME_FIELD_NUMBER: builtins.int
    action_type: builtins.str
    @property
    def custom_action(self) -> global___AutoHealCustomAction: ...
    min_process_execution_time: builtins.str
    def __init__(
        self,
        *,
        action_type: builtins.str = ...,
        custom_action: global___AutoHealCustomAction | None = ...,
        min_process_execution_time: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_action", b"custom_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_type", b"action_type", "custom_action", b"custom_action", "min_process_execution_time", b"min_process_execution_time"]) -> None: ...

global___AutoHealActions = AutoHealActions

@typing_extensions.final
class AutoHealCustomAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    exe: builtins.str
    parameters: builtins.str
    def __init__(
        self,
        *,
        exe: builtins.str = ...,
        parameters: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exe", b"exe", "parameters", b"parameters"]) -> None: ...

global___AutoHealCustomAction = AutoHealCustomAction

@typing_extensions.final
class ApiManagementConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ApiManagementConfig = ApiManagementConfig

@typing_extensions.final
class ApiDefinitionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ApiDefinitionInfo = ApiDefinitionInfo

@typing_extensions.final
class HostNameSslState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SSL_STATE_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    TO_UPDATE_FIELD_NUMBER: builtins.int
    VIRTUAL_IP_FIELD_NUMBER: builtins.int
    host_type: builtins.str
    name: builtins.str
    ssl_state: builtins.str
    thumbprint: builtins.str
    to_update: builtins.bool
    virtual_ip: builtins.str
    def __init__(
        self,
        *,
        host_type: builtins.str = ...,
        name: builtins.str = ...,
        ssl_state: builtins.str = ...,
        thumbprint: builtins.str = ...,
        to_update: builtins.bool = ...,
        virtual_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_type", b"host_type", "name", b"name", "ssl_state", b"ssl_state", "thumbprint", b"thumbprint", "to_update", b"to_update", "virtual_ip", b"virtual_ip"]) -> None: ...

global___HostNameSslState = HostNameSslState

@typing_extensions.final
class CloningInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AppSettingsOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APP_SETTINGS_OVERRIDES_FIELD_NUMBER: builtins.int
    CLONE_CUSTOM_HOST_NAMES_FIELD_NUMBER: builtins.int
    CLONE_SOURCE_CONTROL_FIELD_NUMBER: builtins.int
    CONFIGURE_LOAD_BALANCING_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENT_FIELD_NUMBER: builtins.int
    OVERWRITE_FIELD_NUMBER: builtins.int
    SOURCE_WEB_APP_ID_FIELD_NUMBER: builtins.int
    SOURCE_WEB_APP_LOCATION_FIELD_NUMBER: builtins.int
    TRAFFIC_MANAGER_PROFILE_ID_FIELD_NUMBER: builtins.int
    TRAFFIC_MANAGER_PROFILE_NAME_FIELD_NUMBER: builtins.int
    @property
    def app_settings_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    clone_custom_host_names: builtins.bool
    clone_source_control: builtins.bool
    configure_load_balancing: builtins.bool
    correlation_id: builtins.str
    hosting_environment: builtins.str
    overwrite: builtins.bool
    source_web_app_id: builtins.str
    source_web_app_location: builtins.str
    traffic_manager_profile_id: builtins.str
    traffic_manager_profile_name: builtins.str
    def __init__(
        self,
        *,
        app_settings_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        clone_custom_host_names: builtins.bool = ...,
        clone_source_control: builtins.bool = ...,
        configure_load_balancing: builtins.bool = ...,
        correlation_id: builtins.str = ...,
        hosting_environment: builtins.str = ...,
        overwrite: builtins.bool = ...,
        source_web_app_id: builtins.str = ...,
        source_web_app_location: builtins.str = ...,
        traffic_manager_profile_id: builtins.str = ...,
        traffic_manager_profile_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_settings_overrides", b"app_settings_overrides", "clone_custom_host_names", b"clone_custom_host_names", "clone_source_control", b"clone_source_control", "configure_load_balancing", b"configure_load_balancing", "correlation_id", b"correlation_id", "hosting_environment", b"hosting_environment", "overwrite", b"overwrite", "source_web_app_id", b"source_web_app_id", "source_web_app_location", b"source_web_app_location", "traffic_manager_profile_id", b"traffic_manager_profile_id", "traffic_manager_profile_name", b"traffic_manager_profile_name"]) -> None: ...

global___CloningInfo = CloningInfo

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class ServerfarmsVirtualNetworkConnectionsRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    END_ADDRESS_FIELD_NUMBER: builtins.int
    ROUTE_TYPE_FIELD_NUMBER: builtins.int
    START_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    end_address: builtins.str
    route_type: builtins.str
    start_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        end_address: builtins.str = ...,
        route_type: builtins.str = ...,
        start_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_address", b"end_address", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "route_type", b"route_type", "start_address", b"start_address"]) -> None: ...

global___ServerfarmsVirtualNetworkConnectionsRoutes = ServerfarmsVirtualNetworkConnectionsRoutes

@typing_extensions.final
class ServerfarmsVirtualNetworkConnectionsGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VNET_NAME_FIELD_NUMBER: builtins.int
    VPN_PACKAGE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    vnet_name: builtins.str
    vpn_package_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        vnet_name: builtins.str = ...,
        vpn_package_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "resource_info", b"resource_info", "vnet_name", b"vnet_name", "vpn_package_uri", b"vpn_package_uri"]) -> None: ...

global___ServerfarmsVirtualNetworkConnectionsGateways = ServerfarmsVirtualNetworkConnectionsGateways

@typing_extensions.final
class Serverfarms(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ELASTIC_SCALE_ENABLED_FIELD_NUMBER: builtins.int
    FREE_OFFER_EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENT_PROFILE_FIELD_NUMBER: builtins.int
    HYPER_V_FIELD_NUMBER: builtins.int
    IS_SPOT_FIELD_NUMBER: builtins.int
    IS_XENON_FIELD_NUMBER: builtins.int
    KUBE_ENVIRONMENT_PROFILE_FIELD_NUMBER: builtins.int
    MAXIMUM_ELASTIC_WORKER_COUNT_FIELD_NUMBER: builtins.int
    PER_SITE_SCALING_FIELD_NUMBER: builtins.int
    RESERVED_FIELD_NUMBER: builtins.int
    SPOT_EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    TARGET_WORKER_COUNT_FIELD_NUMBER: builtins.int
    TARGET_WORKER_SIZE_ID_FIELD_NUMBER: builtins.int
    WORKER_TIER_NAME_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    elastic_scale_enabled: builtins.bool
    free_offer_expiration_time: builtins.str
    @property
    def hosting_environment_profile(self) -> global___HostingEnvironmentProfile: ...
    hyper_v: builtins.bool
    is_spot: builtins.bool
    is_xenon: builtins.bool
    @property
    def kube_environment_profile(self) -> global___KubeEnvironmentProfile: ...
    maximum_elastic_worker_count: builtins.int
    per_site_scaling: builtins.bool
    reserved: builtins.bool
    spot_expiration_time: builtins.str
    target_worker_count: builtins.int
    target_worker_size_id: builtins.int
    worker_tier_name: builtins.str
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___SkuDescription: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        elastic_scale_enabled: builtins.bool = ...,
        free_offer_expiration_time: builtins.str = ...,
        hosting_environment_profile: global___HostingEnvironmentProfile | None = ...,
        hyper_v: builtins.bool = ...,
        is_spot: builtins.bool = ...,
        is_xenon: builtins.bool = ...,
        kube_environment_profile: global___KubeEnvironmentProfile | None = ...,
        maximum_elastic_worker_count: builtins.int = ...,
        per_site_scaling: builtins.bool = ...,
        reserved: builtins.bool = ...,
        spot_expiration_time: builtins.str = ...,
        target_worker_count: builtins.int = ...,
        target_worker_size_id: builtins.int = ...,
        worker_tier_name: builtins.str = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___SkuDescription | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extended_location", b"extended_location", "hosting_environment_profile", b"hosting_environment_profile", "kube_environment_profile", b"kube_environment_profile", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elastic_scale_enabled", b"elastic_scale_enabled", "extended_location", b"extended_location", "free_offer_expiration_time", b"free_offer_expiration_time", "hosting_environment_profile", b"hosting_environment_profile", "hyper_v", b"hyper_v", "is_spot", b"is_spot", "is_xenon", b"is_xenon", "kind", b"kind", "kube_environment_profile", b"kube_environment_profile", "location", b"location", "maximum_elastic_worker_count", b"maximum_elastic_worker_count", "name", b"name", "per_site_scaling", b"per_site_scaling", "reserved", b"reserved", "resource_info", b"resource_info", "sku", b"sku", "spot_expiration_time", b"spot_expiration_time", "tags", b"tags", "target_worker_count", b"target_worker_count", "target_worker_size_id", b"target_worker_size_id", "worker_tier_name", b"worker_tier_name", "zone_redundant", b"zone_redundant"]) -> None: ...

global___Serverfarms = Serverfarms

@typing_extensions.final
class KubeEnvironmentProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___KubeEnvironmentProfile = KubeEnvironmentProfile

@typing_extensions.final
class HostingEnvironmentProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___HostingEnvironmentProfile = HostingEnvironmentProfile

@typing_extensions.final
class KubeEnvironments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AKS_RESOURCE_ID_FIELD_NUMBER: builtins.int
    APP_LOGS_CONFIGURATION_FIELD_NUMBER: builtins.int
    ARC_CONFIGURATION_FIELD_NUMBER: builtins.int
    CONTAINER_APPS_CONFIGURATION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_TYPE_FIELD_NUMBER: builtins.int
    INTERNAL_LOAD_BALANCER_ENABLED_FIELD_NUMBER: builtins.int
    STATIC_IP_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    aks_resource_id: builtins.str
    @property
    def app_logs_configuration(self) -> global___AppLogsConfiguration: ...
    @property
    def arc_configuration(self) -> global___ArcConfiguration: ...
    @property
    def container_apps_configuration(self) -> global___ContainerAppsConfiguration: ...
    environment_type: builtins.str
    internal_load_balancer_enabled: builtins.bool
    static_ip: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        aks_resource_id: builtins.str = ...,
        app_logs_configuration: global___AppLogsConfiguration | None = ...,
        arc_configuration: global___ArcConfiguration | None = ...,
        container_apps_configuration: global___ContainerAppsConfiguration | None = ...,
        environment_type: builtins.str = ...,
        internal_load_balancer_enabled: builtins.bool = ...,
        static_ip: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_logs_configuration", b"app_logs_configuration", "arc_configuration", b"arc_configuration", "container_apps_configuration", b"container_apps_configuration", "extended_location", b"extended_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aks_resource_id", b"aks_resource_id", "app_logs_configuration", b"app_logs_configuration", "arc_configuration", b"arc_configuration", "container_apps_configuration", b"container_apps_configuration", "environment_type", b"environment_type", "extended_location", b"extended_location", "internal_load_balancer_enabled", b"internal_load_balancer_enabled", "kind", b"kind", "location", b"location", "name", b"name", "resource_info", b"resource_info", "static_ip", b"static_ip", "tags", b"tags"]) -> None: ...

global___KubeEnvironments = KubeEnvironments

@typing_extensions.final
class ContainerAppsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_SUBNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    CONTROL_PLANE_SUBNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    DAPR_A_I_INSTRUMENTATION_KEY_FIELD_NUMBER: builtins.int
    DOCKER_BRIDGE_CIDR_FIELD_NUMBER: builtins.int
    PLATFORM_RESERVED_CIDR_FIELD_NUMBER: builtins.int
    PLATFORM_RESERVED_DNS_IP_FIELD_NUMBER: builtins.int
    app_subnet_resource_id: builtins.str
    control_plane_subnet_resource_id: builtins.str
    dapr_a_i_instrumentation_key: builtins.str
    docker_bridge_cidr: builtins.str
    platform_reserved_cidr: builtins.str
    platform_reserved_dns_ip: builtins.str
    def __init__(
        self,
        *,
        app_subnet_resource_id: builtins.str = ...,
        control_plane_subnet_resource_id: builtins.str = ...,
        dapr_a_i_instrumentation_key: builtins.str = ...,
        docker_bridge_cidr: builtins.str = ...,
        platform_reserved_cidr: builtins.str = ...,
        platform_reserved_dns_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_subnet_resource_id", b"app_subnet_resource_id", "control_plane_subnet_resource_id", b"control_plane_subnet_resource_id", "dapr_a_i_instrumentation_key", b"dapr_a_i_instrumentation_key", "docker_bridge_cidr", b"docker_bridge_cidr", "platform_reserved_cidr", b"platform_reserved_cidr", "platform_reserved_dns_ip", b"platform_reserved_dns_ip"]) -> None: ...

global___ContainerAppsConfiguration = ContainerAppsConfiguration

@typing_extensions.final
class ArcConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTS_STORAGE_TYPE_FIELD_NUMBER: builtins.int
    ARTIFACT_STORAGE_ACCESS_MODE_FIELD_NUMBER: builtins.int
    ARTIFACT_STORAGE_CLASS_NAME_FIELD_NUMBER: builtins.int
    ARTIFACT_STORAGE_MOUNT_PATH_FIELD_NUMBER: builtins.int
    ARTIFACT_STORAGE_NODE_NAME_FIELD_NUMBER: builtins.int
    FRONT_END_SERVICE_CONFIGURATION_FIELD_NUMBER: builtins.int
    KUBE_CONFIG_FIELD_NUMBER: builtins.int
    artifacts_storage_type: builtins.str
    artifact_storage_access_mode: builtins.str
    artifact_storage_class_name: builtins.str
    artifact_storage_mount_path: builtins.str
    artifact_storage_node_name: builtins.str
    @property
    def front_end_service_configuration(self) -> global___FrontEndConfiguration: ...
    kube_config: builtins.str
    def __init__(
        self,
        *,
        artifacts_storage_type: builtins.str = ...,
        artifact_storage_access_mode: builtins.str = ...,
        artifact_storage_class_name: builtins.str = ...,
        artifact_storage_mount_path: builtins.str = ...,
        artifact_storage_node_name: builtins.str = ...,
        front_end_service_configuration: global___FrontEndConfiguration | None = ...,
        kube_config: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["front_end_service_configuration", b"front_end_service_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_storage_access_mode", b"artifact_storage_access_mode", "artifact_storage_class_name", b"artifact_storage_class_name", "artifact_storage_mount_path", b"artifact_storage_mount_path", "artifact_storage_node_name", b"artifact_storage_node_name", "artifacts_storage_type", b"artifacts_storage_type", "front_end_service_configuration", b"front_end_service_configuration", "kube_config", b"kube_config"]) -> None: ...

global___ArcConfiguration = ArcConfiguration

@typing_extensions.final
class FrontEndConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    kind: builtins.str
    def __init__(
        self,
        *,
        kind: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind"]) -> None: ...

global___FrontEndConfiguration = FrontEndConfiguration

@typing_extensions.final
class AppLogsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    LOG_ANALYTICS_CONFIGURATION_FIELD_NUMBER: builtins.int
    destination: builtins.str
    @property
    def log_analytics_configuration(self) -> global___LogAnalyticsConfiguration: ...
    def __init__(
        self,
        *,
        destination: builtins.str = ...,
        log_analytics_configuration: global___LogAnalyticsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_analytics_configuration", b"log_analytics_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "log_analytics_configuration", b"log_analytics_configuration"]) -> None: ...

global___AppLogsConfiguration = AppLogsConfiguration

@typing_extensions.final
class LogAnalyticsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    SHARED_KEY_FIELD_NUMBER: builtins.int
    customer_id: builtins.str
    shared_key: builtins.str
    def __init__(
        self,
        *,
        customer_id: builtins.str = ...,
        shared_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_id", b"customer_id", "shared_key", b"shared_key"]) -> None: ...

global___LogAnalyticsConfiguration = LogAnalyticsConfiguration

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ExtendedLocation = ExtendedLocation

@typing_extensions.final
class HostingEnvironmentsWorkerPools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COMPUTE_MODE_FIELD_NUMBER: builtins.int
    WORKER_COUNT_FIELD_NUMBER: builtins.int
    WORKER_SIZE_FIELD_NUMBER: builtins.int
    WORKER_SIZE_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    compute_mode: builtins.str
    worker_count: builtins.int
    worker_size: builtins.str
    worker_size_id: builtins.int
    @property
    def sku(self) -> global___SkuDescription: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        compute_mode: builtins.str = ...,
        worker_count: builtins.int = ...,
        worker_size: builtins.str = ...,
        worker_size_id: builtins.int = ...,
        sku: global___SkuDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_mode", b"compute_mode", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "worker_count", b"worker_count", "worker_size", b"worker_size", "worker_size_id", b"worker_size_id"]) -> None: ...

global___HostingEnvironmentsWorkerPools = HostingEnvironmentsWorkerPools

@typing_extensions.final
class HostingEnvironmentsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___HostingEnvironmentsPrivateEndpointConnections = HostingEnvironmentsPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkConnectionState = PrivateLinkConnectionState

@typing_extensions.final
class HostingEnvironmentsMultiRolePools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COMPUTE_MODE_FIELD_NUMBER: builtins.int
    WORKER_COUNT_FIELD_NUMBER: builtins.int
    WORKER_SIZE_FIELD_NUMBER: builtins.int
    WORKER_SIZE_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    name: builtins.str
    compute_mode: builtins.str
    worker_count: builtins.int
    worker_size: builtins.str
    worker_size_id: builtins.int
    @property
    def sku(self) -> global___SkuDescription: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        compute_mode: builtins.str = ...,
        worker_count: builtins.int = ...,
        worker_size: builtins.str = ...,
        worker_size_id: builtins.int = ...,
        sku: global___SkuDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_mode", b"compute_mode", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "worker_count", b"worker_count", "worker_size", b"worker_size", "worker_size_id", b"worker_size_id"]) -> None: ...

global___HostingEnvironmentsMultiRolePools = HostingEnvironmentsMultiRolePools

@typing_extensions.final
class SkuDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPABILITIES_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SKU_CAPACITY_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Capability]: ...
    capacity: builtins.int
    family: builtins.str
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    size: builtins.str
    @property
    def sku_capacity(self) -> global___SkuCapacity: ...
    tier: builtins.str
    def __init__(
        self,
        *,
        capabilities: collections.abc.Iterable[global___Capability] | None = ...,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        locations: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        sku_capacity: global___SkuCapacity | None = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sku_capacity", b"sku_capacity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capabilities", b"capabilities", "capacity", b"capacity", "family", b"family", "locations", b"locations", "name", b"name", "size", b"size", "sku_capacity", b"sku_capacity", "tier", b"tier"]) -> None: ...

global___SkuDescription = SkuDescription

@typing_extensions.final
class SkuCapacity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_FIELD_NUMBER: builtins.int
    ELASTIC_MAXIMUM_FIELD_NUMBER: builtins.int
    MAXIMUM_FIELD_NUMBER: builtins.int
    MINIMUM_FIELD_NUMBER: builtins.int
    SCALE_TYPE_FIELD_NUMBER: builtins.int
    default: builtins.int
    elastic_maximum: builtins.int
    maximum: builtins.int
    minimum: builtins.int
    scale_type: builtins.str
    def __init__(
        self,
        *,
        default: builtins.int = ...,
        elastic_maximum: builtins.int = ...,
        maximum: builtins.int = ...,
        minimum: builtins.int = ...,
        scale_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default", b"default", "elastic_maximum", b"elastic_maximum", "maximum", b"maximum", "minimum", b"minimum", "scale_type", b"scale_type"]) -> None: ...

global___SkuCapacity = SkuCapacity

@typing_extensions.final
class Capability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    reason: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        reason: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "reason", b"reason", "value", b"value"]) -> None: ...

global___Capability = Capability

@typing_extensions.final
class HostingEnvironmentsConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___HostingEnvironmentsConfigurations = HostingEnvironmentsConfigurations

@typing_extensions.final
class HostingEnvironments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_SETTINGS_FIELD_NUMBER: builtins.int
    CUSTOM_DNS_SUFFIX_CONFIGURATION_FIELD_NUMBER: builtins.int
    DEDICATED_HOST_COUNT_FIELD_NUMBER: builtins.int
    DNS_SUFFIX_FIELD_NUMBER: builtins.int
    FRONT_END_SCALE_FACTOR_FIELD_NUMBER: builtins.int
    INTERNAL_LOAD_BALANCING_MODE_FIELD_NUMBER: builtins.int
    IPSSL_ADDRESS_COUNT_FIELD_NUMBER: builtins.int
    MULTI_SIZE_FIELD_NUMBER: builtins.int
    NETWORKING_CONFIGURATION_FIELD_NUMBER: builtins.int
    UPGRADE_PREFERENCE_FIELD_NUMBER: builtins.int
    USER_WHITELISTED_IP_RANGES_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENTS_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENTS_MULTI_ROLE_POOLS_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    HOSTING_ENVIRONMENTS_WORKER_POOLS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def cluster_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NameValuePair]: ...
    @property
    def custom_dns_suffix_configuration(self) -> global___CustomDnsSuffixConfiguration: ...
    dedicated_host_count: builtins.int
    dns_suffix: builtins.str
    front_end_scale_factor: builtins.int
    internal_load_balancing_mode: builtins.str
    ipssl_address_count: builtins.int
    multi_size: builtins.str
    @property
    def networking_configuration(self) -> global___AseV3NetworkingConfiguration: ...
    upgrade_preference: builtins.str
    @property
    def user_whitelisted_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def virtual_network(self) -> global___VirtualNetworkProfile: ...
    zone_redundant: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def hosting_environments_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostingEnvironmentsConfigurations]: ...
    @property
    def hosting_environments_multi_role_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostingEnvironmentsMultiRolePools]: ...
    @property
    def hosting_environments_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostingEnvironmentsPrivateEndpointConnections]: ...
    @property
    def hosting_environments_worker_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostingEnvironmentsWorkerPools]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        cluster_settings: collections.abc.Iterable[global___NameValuePair] | None = ...,
        custom_dns_suffix_configuration: global___CustomDnsSuffixConfiguration | None = ...,
        dedicated_host_count: builtins.int = ...,
        dns_suffix: builtins.str = ...,
        front_end_scale_factor: builtins.int = ...,
        internal_load_balancing_mode: builtins.str = ...,
        ipssl_address_count: builtins.int = ...,
        multi_size: builtins.str = ...,
        networking_configuration: global___AseV3NetworkingConfiguration | None = ...,
        upgrade_preference: builtins.str = ...,
        user_whitelisted_ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        virtual_network: global___VirtualNetworkProfile | None = ...,
        zone_redundant: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        hosting_environments_configurations: collections.abc.Iterable[global___HostingEnvironmentsConfigurations] | None = ...,
        hosting_environments_multi_role_pools: collections.abc.Iterable[global___HostingEnvironmentsMultiRolePools] | None = ...,
        hosting_environments_private_endpoint_connections: collections.abc.Iterable[global___HostingEnvironmentsPrivateEndpointConnections] | None = ...,
        hosting_environments_worker_pools: collections.abc.Iterable[global___HostingEnvironmentsWorkerPools] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_dns_suffix_configuration", b"custom_dns_suffix_configuration", "networking_configuration", b"networking_configuration", "resource_info", b"resource_info", "virtual_network", b"virtual_network"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_settings", b"cluster_settings", "custom_dns_suffix_configuration", b"custom_dns_suffix_configuration", "dedicated_host_count", b"dedicated_host_count", "dns_suffix", b"dns_suffix", "front_end_scale_factor", b"front_end_scale_factor", "hosting_environments_configurations", b"hosting_environments_configurations", "hosting_environments_multi_role_pools", b"hosting_environments_multi_role_pools", "hosting_environments_private_endpoint_connections", b"hosting_environments_private_endpoint_connections", "hosting_environments_worker_pools", b"hosting_environments_worker_pools", "internal_load_balancing_mode", b"internal_load_balancing_mode", "ipssl_address_count", b"ipssl_address_count", "kind", b"kind", "location", b"location", "multi_size", b"multi_size", "name", b"name", "networking_configuration", b"networking_configuration", "resource_info", b"resource_info", "tags", b"tags", "upgrade_preference", b"upgrade_preference", "user_whitelisted_ip_ranges", b"user_whitelisted_ip_ranges", "virtual_network", b"virtual_network", "zone_redundant", b"zone_redundant"]) -> None: ...

global___HostingEnvironments = HostingEnvironments

@typing_extensions.final
class VirtualNetworkProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    id: builtins.str
    subnet: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        subnet: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "subnet", b"subnet"]) -> None: ...

global___VirtualNetworkProfile = VirtualNetworkProfile

@typing_extensions.final
class AseV3NetworkingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    ALLOW_NEW_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    FTP_ENABLED_FIELD_NUMBER: builtins.int
    INBOUND_IP_ADDRESS_OVERRIDE_FIELD_NUMBER: builtins.int
    REMOTE_DEBUG_ENABLED_FIELD_NUMBER: builtins.int
    kind: builtins.str
    allow_new_private_endpoint_connections: builtins.bool
    ftp_enabled: builtins.bool
    inbound_ip_address_override: builtins.str
    remote_debug_enabled: builtins.bool
    def __init__(
        self,
        *,
        kind: builtins.str = ...,
        allow_new_private_endpoint_connections: builtins.bool = ...,
        ftp_enabled: builtins.bool = ...,
        inbound_ip_address_override: builtins.str = ...,
        remote_debug_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_new_private_endpoint_connections", b"allow_new_private_endpoint_connections", "ftp_enabled", b"ftp_enabled", "inbound_ip_address_override", b"inbound_ip_address_override", "kind", b"kind", "remote_debug_enabled", b"remote_debug_enabled"]) -> None: ...

global___AseV3NetworkingConfiguration = AseV3NetworkingConfiguration

@typing_extensions.final
class CustomDnsSuffixConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    CERTIFICATE_URL_FIELD_NUMBER: builtins.int
    DNS_SUFFIX_FIELD_NUMBER: builtins.int
    KEY_VAULT_REFERENCE_IDENTITY_FIELD_NUMBER: builtins.int
    kind: builtins.str
    certificate_url: builtins.str
    dns_suffix: builtins.str
    key_vault_reference_identity: builtins.str
    def __init__(
        self,
        *,
        kind: builtins.str = ...,
        certificate_url: builtins.str = ...,
        dns_suffix: builtins.str = ...,
        key_vault_reference_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_url", b"certificate_url", "dns_suffix", b"dns_suffix", "key_vault_reference_identity", b"key_vault_reference_identity", "kind", b"kind"]) -> None: ...

global___CustomDnsSuffixConfiguration = CustomDnsSuffixConfiguration

@typing_extensions.final
class NameValuePair(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___NameValuePair = NameValuePair

@typing_extensions.final
class ContainerApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    KUBE_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def configuration(self) -> global___Configuration: ...
    kube_environment_id: builtins.str
    @property
    def template(self) -> global___Template: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        configuration: global___Configuration | None = ...,
        kube_environment_id: builtins.str = ...,
        template: global___Template | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "resource_info", b"resource_info", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "kind", b"kind", "kube_environment_id", b"kube_environment_id", "location", b"location", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "template", b"template"]) -> None: ...

global___ContainerApps = ContainerApps

@typing_extensions.final
class Template(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINERS_FIELD_NUMBER: builtins.int
    DAPR_FIELD_NUMBER: builtins.int
    REVISION_SUFFIX_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    @property
    def containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Container]: ...
    @property
    def dapr(self) -> global___Dapr: ...
    revision_suffix: builtins.str
    @property
    def scale(self) -> global___Scale: ...
    def __init__(
        self,
        *,
        containers: collections.abc.Iterable[global___Container] | None = ...,
        dapr: global___Dapr | None = ...,
        revision_suffix: builtins.str = ...,
        scale: global___Scale | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dapr", b"dapr", "scale", b"scale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["containers", b"containers", "dapr", b"dapr", "revision_suffix", b"revision_suffix", "scale", b"scale"]) -> None: ...

global___Template = Template

@typing_extensions.final
class Scale(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    max_replicas: builtins.int
    min_replicas: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRule]: ...
    def __init__(
        self,
        *,
        max_replicas: builtins.int = ...,
        min_replicas: builtins.int = ...,
        rules: collections.abc.Iterable[global___ScaleRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_replicas", b"max_replicas", "min_replicas", b"min_replicas", "rules", b"rules"]) -> None: ...

global___Scale = Scale

@typing_extensions.final
class ScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_QUEUE_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def azure_queue(self) -> global___QueueScaleRule: ...
    @property
    def custom(self) -> global___CustomScaleRule: ...
    @property
    def http(self) -> global___HttpScaleRule: ...
    name: builtins.str
    def __init__(
        self,
        *,
        azure_queue: global___QueueScaleRule | None = ...,
        custom: global___CustomScaleRule | None = ...,
        http: global___HttpScaleRule | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_queue", b"azure_queue", "custom", b"custom", "http", b"http"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_queue", b"azure_queue", "custom", b"custom", "http", b"http", "name", b"name"]) -> None: ...

global___ScaleRule = ScaleRule

@typing_extensions.final
class HttpScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "metadata", b"metadata"]) -> None: ...

global___HttpScaleRule = HttpScaleRule

@typing_extensions.final
class CustomScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "metadata", b"metadata", "type", b"type"]) -> None: ...

global___CustomScaleRule = CustomScaleRule

@typing_extensions.final
class QueueScaleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FIELD_NUMBER: builtins.int
    QUEUE_LENGTH_FIELD_NUMBER: builtins.int
    QUEUE_NAME_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScaleRuleAuth]: ...
    queue_length: builtins.int
    queue_name: builtins.str
    def __init__(
        self,
        *,
        auth: collections.abc.Iterable[global___ScaleRuleAuth] | None = ...,
        queue_length: builtins.int = ...,
        queue_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "queue_length", b"queue_length", "queue_name", b"queue_name"]) -> None: ...

global___QueueScaleRule = QueueScaleRule

@typing_extensions.final
class ScaleRuleAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_REF_FIELD_NUMBER: builtins.int
    TRIGGER_PARAMETER_FIELD_NUMBER: builtins.int
    secret_ref: builtins.str
    trigger_parameter: builtins.str
    def __init__(
        self,
        *,
        secret_ref: builtins.str = ...,
        trigger_parameter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_ref", b"secret_ref", "trigger_parameter", b"trigger_parameter"]) -> None: ...

global___ScaleRuleAuth = ScaleRuleAuth

@typing_extensions.final
class Dapr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    APP_PORT_FIELD_NUMBER: builtins.int
    COMPONENTS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    app_port: builtins.int
    @property
    def components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaprComponent]: ...
    enabled: builtins.bool
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        app_port: builtins.int = ...,
        components: collections.abc.Iterable[global___DaprComponent] | None = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "app_port", b"app_port", "components", b"components", "enabled", b"enabled"]) -> None: ...

global___Dapr = Dapr

@typing_extensions.final
class DaprComponent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaprMetadata]: ...
    name: builtins.str
    type: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        metadata: collections.abc.Iterable[global___DaprMetadata] | None = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "name", b"name", "type", b"type", "version", b"version"]) -> None: ...

global___DaprComponent = DaprComponent

@typing_extensions.final
class DaprMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    secret_ref: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        secret_ref: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "secret_ref", b"secret_ref", "value", b"value"]) -> None: ...

global___DaprMetadata = DaprMetadata

@typing_extensions.final
class Container(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentVar]: ...
    image: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        env: collections.abc.Iterable[global___EnvironmentVar] | None = ...,
        image: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "command", b"command", "env", b"env", "image", b"image", "name", b"name"]) -> None: ...

global___Container = Container

@typing_extensions.final
class EnvironmentVar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    secret_ref: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        secret_ref: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "secret_ref", b"secret_ref", "value", b"value"]) -> None: ...

global___EnvironmentVar = EnvironmentVar

@typing_extensions.final
class Configuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_REVISIONS_MODE_FIELD_NUMBER: builtins.int
    INGRESS_FIELD_NUMBER: builtins.int
    REGISTRIES_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    active_revisions_mode: builtins.str
    @property
    def ingress(self) -> global___Ingress: ...
    @property
    def registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistryCredentials]: ...
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]: ...
    def __init__(
        self,
        *,
        active_revisions_mode: builtins.str = ...,
        ingress: global___Ingress | None = ...,
        registries: collections.abc.Iterable[global___RegistryCredentials] | None = ...,
        secrets: collections.abc.Iterable[global___Secret] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ingress", b"ingress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_revisions_mode", b"active_revisions_mode", "ingress", b"ingress", "registries", b"registries", "secrets", b"secrets"]) -> None: ...

global___Configuration = Configuration

@typing_extensions.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___Secret = Secret

@typing_extensions.final
class RegistryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_SECRET_REF_FIELD_NUMBER: builtins.int
    SERVER_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    password_secret_ref: builtins.str
    server: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        password_secret_ref: builtins.str = ...,
        server: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["password_secret_ref", b"password_secret_ref", "server", b"server", "username", b"username"]) -> None: ...

global___RegistryCredentials = RegistryCredentials

@typing_extensions.final
class Ingress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_INSECURE_FIELD_NUMBER: builtins.int
    EXTERNAL_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    TRAFFIC_FIELD_NUMBER: builtins.int
    TRANSPORT_FIELD_NUMBER: builtins.int
    allow_insecure: builtins.bool
    external: builtins.bool
    target_port: builtins.int
    @property
    def traffic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TrafficWeight]: ...
    transport: builtins.str
    def __init__(
        self,
        *,
        allow_insecure: builtins.bool = ...,
        external: builtins.bool = ...,
        target_port: builtins.int = ...,
        traffic: collections.abc.Iterable[global___TrafficWeight] | None = ...,
        transport: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_insecure", b"allow_insecure", "external", b"external", "target_port", b"target_port", "traffic", b"traffic", "transport", b"transport"]) -> None: ...

global___Ingress = Ingress

@typing_extensions.final
class TrafficWeight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LATEST_REVISION_FIELD_NUMBER: builtins.int
    REVISION_NAME_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    latest_revision: builtins.bool
    revision_name: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        latest_revision: builtins.bool = ...,
        revision_name: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["latest_revision", b"latest_revision", "revision_name", b"revision_name", "weight", b"weight"]) -> None: ...

global___TrafficWeight = TrafficWeight

@typing_extensions.final
class Certificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CANONICAL_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_VALIDATION_METHOD_FIELD_NUMBER: builtins.int
    HOST_NAMES_FIELD_NUMBER: builtins.int
    KEY_VAULT_ID_FIELD_NUMBER: builtins.int
    KEY_VAULT_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PFX_BLOB_FIELD_NUMBER: builtins.int
    SERVER_FARM_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    canonical_name: builtins.str
    domain_validation_method: builtins.str
    @property
    def host_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key_vault_id: builtins.str
    key_vault_secret_name: builtins.str
    password: builtins.str
    pfx_blob: builtins.str
    server_farm_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        canonical_name: builtins.str = ...,
        domain_validation_method: builtins.str = ...,
        host_names: collections.abc.Iterable[builtins.str] | None = ...,
        key_vault_id: builtins.str = ...,
        key_vault_secret_name: builtins.str = ...,
        password: builtins.str = ...,
        pfx_blob: builtins.str = ...,
        server_farm_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["canonical_name", b"canonical_name", "domain_validation_method", b"domain_validation_method", "host_names", b"host_names", "key_vault_id", b"key_vault_id", "key_vault_secret_name", b"key_vault_secret_name", "kind", b"kind", "location", b"location", "name", b"name", "password", b"password", "pfx_blob", b"pfx_blob", "resource_info", b"resource_info", "server_farm_id", b"server_farm_id", "tags", b"tags"]) -> None: ...

global___Certificates = Certificates
